@@ -22,4 +22,16 @@ module fft_val_define
   complex(kind(0d0)), allocatable, dimension(:,:) :: uk
   complex(kind(0d0)), allocatable, dimension(:,:) :: vk
 
+!-- For ISPACK
+
+  double precision, allocatable, dimension(:,:) :: zor_isp
+  double precision, allocatable, dimension(:,:) :: psior_isp
+  double precision, allocatable, dimension(:,:) :: ur_isp
+  double precision, allocatable, dimension(:,:) :: vr_isp
+  double precision, allocatable, dimension(:,:) :: zko_isp
+  double precision, allocatable, dimension(:,:) :: psiko_isp
+  double precision, allocatable, dimension(:,:) :: uk_isp
+  double precision, allocatable, dimension(:,:) :: vk_isp
+  double precision, allocatable, dimension(:,:) :: tmp_work
+
 end module fft_val_define
