@@ -1,5 +1,5 @@
 program solver
-! ƻ 2007 Υޥ󱲥ǥ
+! 中道 2007 のカルマン渦モデル
   use gtool_history
   use Derivation
   use max_min
@@ -19,13 +19,13 @@ program solver
 
   implicit none
 
-!-- do loop ѿ
+!-- do loop 用変数の定義
   integer :: i, j, it, counter_psi
 
-!-- ƥݥѿ
+!-- テンポラリ実変数
   real :: mean_psi, chan_leng
 
-!-- namelist ɤ߹
+!-- namelist の読み込み
 
   call read_name()
 
@@ -33,20 +33,20 @@ program solver
 
   call val_allocate()
 
-!-- ʻκ
+!-- 格子点の再定義
 
   call val_coordinate()
 
-!-- Ͳ (׻ΰ䶭, ä˥ݥ׻ˤĤ)
+!-- 初期値化 (計算領域の設定や境界条件の設定, 特にポアソン計算について)
 
 write(*,*) "starting initialization."
 
-!-- ǡɤ߹
+!-- 初期条件データから読み込み
 
   call read_file_text( trim(inner_file), nx, ny, cval, skip=1,  &
   &                    forma='('//trim(adjustl(i2c_convert(nx)))//'a1)' )
 
-!-- psi, omega Ф, ƶե饰.
+!-- psi, omega に対して, 各境界条件フラグを設定.
 
   do j=1,ny
      do i=1,nx
@@ -66,7 +66,7 @@ write(*,*) "starting initialization."
      end do
   end do
 
-  boundary='1112'  ! psi ϥݥ󥽥ФϤʬ.
+  boundary='1112'  ! psi はポアソンソルバに渡す分だけ作成.
 
   do j=1,ny
      ibo(1,j)=1
@@ -78,7 +78,7 @@ write(*,*) "starting initialization."
      ibo(i,ny)=1
   end do
 
-!-- ͺ
+!-- 初期値作成
 
   if(len_trim(finame)==0)then
      omega_old=0.0
@@ -87,13 +87,17 @@ write(*,*) "starting initialization."
 
      do j=1,ny
         do i=1,nx
-if(j<=ny/2)then
+!-- For uniform ubar
            psi_old(i,j)=ubar*(y(j)-0.5*chan_leng)
-else
-           psi_old(i,j)=(2.0*ubar/chan_leng)*(chan_leng*y(j)-0.5*y(j)**2)  &
-  &                     -0.75*ubar*chan_leng
-end if
-!           omega_old(i,j)=exp(-((x(i)-0.5*(x(nx)-x(1)))**2+(y(j)-0.5*(y(ny)-y(1)))**2))
+
+!-- For horizontal shear in ubar
+!if(j<=ny/2)then
+!           psi_old(i,j)=ubar*(y(j)-0.5*chan_leng)
+!else
+!           psi_old(i,j)=(2.0*ubar/chan_leng)*(chan_leng*y(j)-0.5*y(j)**2)  &
+!  &                     -0.75*ubar*chan_leng
+!end if
+!!           omega_old(i,j)=exp(-((x(i)-0.5*(x(nx)-x(1)))**2+(y(j)-0.5*(y(ny)-y(1)))**2))
         end do
      end do
 
@@ -109,13 +113,13 @@ end if
      call make_initialize()
   end if
 
-!-- ͤ.
+!-- 境界強制値の設定.
 
   bndp=0.0
   bndo=0.0
 
-  !-- ʲǶͤꤷƤ뤬, եå̤궯̤ξ
-  !   Ǵ()ƤΤǹԤʤ.
+  !-- 以下で境界値を設定しているが, フラックス量や固定強制量がゼロの場合は
+  !   上で既に設定(初期化)しているので行わない.
   do j=1,ny
      bndp(1,j)=psi_old(1,j)
   end do
@@ -125,7 +129,7 @@ end if
      bndp(i,ny)=bndp(1,ny)
   end do
 
-!-- Ǥ psi ͤ϶ psi ʿͤѤ뤳Ȥˤ.
+!-- 内部境界での psi の値は境界廻りの psi の平均値を用いることにする.
 
   mean_psi=0.0
   counter_psi=0
@@ -157,7 +161,7 @@ end if
 
   write(*,*) "normally pass the initialization."
 
-!-- ϥեν
+!-- 出力ファイルの初期化
   call HistoryCreate( file=trim(foname), title='Karman result data', &
   & source='test', institution='test', dims=(/'x', 'y', 't'/),  &
   & dimsizes=(/nx,ny, 0/),  & 
@@ -181,7 +185,7 @@ end if
 
   write(*,*) "time integration start."
 
-  !-- ν (ͤν)
+  !-- 出力等の処理 (初期値の出力)
 
   call calc_wind( x, y, psi_old, u_dmp, v_dmp, undef=undef )
 
@@ -203,17 +207,17 @@ end if
   call HistoryPut( 'u', u_dmp )
   call HistoryPut( 'v', v_dmp )
 
-!-- solver 
+!-- solver スタート
 
   do it=1,nt
 
      call time_schematic( it )
 
-  !-- ƥåפοʤ߶
+  !-- ステップの進み具合出力
      write(*,*) "This step is ", it, "(time =", real(it)*dt, "[s])."
 
-     !-- ν (2)
-     if(mod(it,dmpstp)==0)then  ! ѴԤ¿Ϥ.
+     !-- 出力等の処理 (2)
+     if(mod(it,dmpstp)==0)then  ! 逆変換を行い実数出力する.
 
         do j=1,ny
            do i=1,nx
@@ -237,7 +241,7 @@ end if
 
   end do
 
-!-- solver ȥå
+!-- solver ストップ
 
   write(*,*) "solver is normally."
 
