@@ -22,43 +22,43 @@ subroutine read_name_mpi()
 
 !-- following : MPI broadcasting (sender)
 
-     call MPI_BCAST( nr, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( hnt, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( nt, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( rmin, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( dr, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( dt, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( dmpstp, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( finame(1:80), 80, MPI_CHARACTER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( foname(1:80), 80, MPI_CHARACTER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( ni, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( nl_flag, 1, MPI_LOGICAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( r_dmp, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( time_flag(1:1), 1, MPI_CHARACTER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( force_flag(1:10), 10, MPI_CHARACTER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( diff_r, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( diff_t, 1, MPI_REAL, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-     call MPI_BCAST( init_n, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
-
-     call MPI_BCAST( proc, 1, MPI_INTEGER, MY_RANK,  &
-  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( nr, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( hnt, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( nt, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( rmin, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( dr, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( dt, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( dmpstp, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( finame(1:80), 80, MPI_CHARACTER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( foname(1:80), 80, MPI_CHARACTER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( ni, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( nl_flag, 1, MPI_LOGICAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( r_dmp, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( time_flag(1:1), 1, MPI_CHARACTER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( force_flag(1:10), 10, MPI_CHARACTER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( diff_r, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( diff_t, 1, MPI_REAL, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!     call MPI_BCAST( init_n, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
+!
+!     call MPI_BCAST( proc, 1, MPI_INTEGER, MY_RANK,  &
+!  &                  MPI_COMM_WORLD, IERROR )
 
   end if
 
@@ -66,7 +66,7 @@ subroutine read_name_mpi()
 
 !-- following : MPI Broadcasting (receiver)
 
-  if(MY_RANK/=0)then
+!  if(MY_RANK/=0)then
 
      call MPI_BCAST( nr, 1, MPI_INTEGER, 0,  &
   &                  MPI_COMM_WORLD, IERROR )
@@ -106,7 +106,7 @@ subroutine read_name_mpi()
      call MPI_BCAST( proc, 1, MPI_INTEGER, 0,  &
   &                  MPI_COMM_WORLD, IERROR )
 
-  end if
+!  end if
 
   if(mod((nr-2),proc)/=0)then
      if(MY_RANK==0)then
