@@ -1,7 +1,7 @@
 module time_scheme
-! ֥ऴȤ˷׻Ԥ⥸塼
-! force_solv Ƿ׻ͤ򥹥˹碌Ƴ꿶,
-! ֥ƥåפȯŸ.
+! 時間スキームごとに計算を行うモジュール
+! force_solv で計算した強制項の値をスキームに合わせて割り振り,
+! 時間ステップを発展させる.
   use Derivation
   use ffts
   use max_min
@@ -23,15 +23,15 @@ contains
 subroutine time_schematic( step )
 
   implicit none
-  integer, intent(in) :: step  ! ॹƥåֹ
+  integer, intent(in) :: step  ! タイムステップ番号
   integer :: ct, i, j
 
-!-- ڥȥѿʬ
+!-- スペクトル変数を実部・虚部に分割
 
   select case (time_flag(1:1))
-  case ('1')  ! RK4 
+  case ('1')  ! RK4 スキーム
 
-  !-- ѿι
+  !-- 変数の更新
      do j=1,ntheta
         do i=1,nr
            ucp_tmp(i,j)=ucp_new(i,j)
@@ -43,7 +43,7 @@ subroutine time_schematic( step )
         end do
      end do
 
-  !-- RK4 ΤȤΤѤѿν force_solv ȤΩ RK4 ΤȤΤư.
+  !-- RK4 のときのみ用いる全強制変数の初期化 force_solv とは独立で RK4 のときのみ動作する.
 
      call complex_init( forceua )
      call complex_init( forceva )
@@ -56,7 +56,7 @@ subroutine time_schematic( step )
 !        end do
 !     end do
 
-     do ct=1,4  ! RK4 η򤽤줾׻
+     do ct=1,4  ! RK4 の傾きをそれぞれ計算
 
      !-- MPI communicating (data communication from both sides)
      !-- 1st, scalar values
@@ -65,7 +65,7 @@ subroutine time_schematic( step )
      !-- 2nd, complex values
         call auto_comm_mpi_complex()
 
-     !-- ׻.
+     !-- 強制項を計算.
 
         call force()
 
@@ -97,7 +97,7 @@ subroutine time_schematic( step )
 !write(*,*) "forcev", forcev
 !write(*,*) "forceh", forceh
 
-!--  ʬ (RK4 ˡ)
+!--  時間積分 (RK4 法)
 
            select case (ct)
            case (1)
@@ -128,7 +128,7 @@ subroutine time_schematic( step )
         end do
 !$omp end do
 !$omp end parallel
-!-- 
+!-- 境界条件の設定
 
         if(MY_RANK==0)then
            do j=1,hnt+1
@@ -146,7 +146,7 @@ subroutine time_schematic( step )
            end if
         end if
 
-!-- ʣǶˤĤƤ, ׻, ֤.
+!-- 複素共役の配列については, 計算せずに, 共役を返すだけ.
         do j=2,hnt+1
            do i=1,nr
               ucp_new(i,hnt+j)=conjg(ucp_new(i,hnt-j+3))
@@ -157,15 +157,15 @@ subroutine time_schematic( step )
 
      end do
 
-  case ('2')  ! Leap Frog 
+  case ('2')  ! Leap Frog スキーム
 
      if(step==1)then
         do j=1,hnt+1
            do i=2,nr
-              ucp_tmp(i,j)=ucp_new(i,j)  ! old ()  tmp (1 ƥå) .
+              ucp_tmp(i,j)=ucp_new(i,j)  ! old (今) を tmp (1 ステップ前) に.
               vcp_tmp(i,j)=vcp_new(i,j)
               hcp_tmp(i,j)=hcp_new(i,j)
-              ucp_old(i,j)=ucp_new(i,j)  ! new (1 ƥå)  old () .
+              ucp_old(i,j)=ucp_new(i,j)  ! new (1 ステップ先) を old (今) に.
               vcp_old(i,j)=vcp_new(i,j)
               hcp_old(i,j)=hcp_new(i,j)
            end do
@@ -173,10 +173,10 @@ subroutine time_schematic( step )
      else
         do j=1,hnt+1
            do i=2,nr
-              ucp_tmp(i,j)=ucp_old(i,j)  ! old ()  tmp (1 ƥå) .
+              ucp_tmp(i,j)=ucp_old(i,j)  ! old (今) を tmp (1 ステップ前) に.
               vcp_tmp(i,j)=vcp_old(i,j)
               hcp_tmp(i,j)=hcp_old(i,j)
-              ucp_old(i,j)=ucp_new(i,j)  ! new (1 ƥå)  old () .
+              ucp_old(i,j)=ucp_new(i,j)  ! new (1 ステップ先) を old (今) に.
               vcp_old(i,j)=vcp_new(i,j)
               hcp_old(i,j)=hcp_new(i,j)
            end do
@@ -190,7 +190,7 @@ subroutine time_schematic( step )
   !-- 2nd, complex values
      call auto_comm_mpi_complex()
 
-  !-- ׻.
+  !-- 強制項を計算.
 
      call force()
 
@@ -224,7 +224,7 @@ subroutine time_schematic( step )
 
      end if
 
-!-- 
+!-- 境界条件の設定
 
      if(MY_RANK==0)then
         do j=1,hnt+1
@@ -242,7 +242,7 @@ subroutine time_schematic( step )
         end if
      end if
 
-!-- ʣǶˤĤƤ, ׻, ֤.
+!-- 複素共役の配列については, 計算せずに, 共役を返すだけ.
      do j=2,hnt+1
         do i=1,nr
            ucp_new(i,hnt+j)=conjg(ucp_new(i,hnt-j+3))
