@@ -1,5 +1,5 @@
 module force_solv
-! ׻⥸塼
+! 強制項を計算するモジュール
   use Derivation
   use ffts
   use max_min
@@ -21,7 +21,7 @@ subroutine force()
 
   integer :: i, j
 
-  !-- ν
+  !-- 強制項の初期化
   call complex_init( forceu )
   call complex_init( forcev )
   call complex_init( forceh )
@@ -33,15 +33,15 @@ subroutine force()
 !        end do
 !     end do
 
-!-- ڥȥѿʬ
+!-- スペクトル変数を実部・虚部に分割
 
-!-- ֤ν°ѿζʬ׻
+!-- 時間の従属変数の空間微分を計算
 
   call grad_1d( rv, ub, dubdr )
   call grad_1d( rs, hb, dhbdr )
   call grad_1d( rv, vb, dvbdr )
 
-  !-- ܾΰή
+  !-- 基本場の移流項
 
   do i=1,nr
      ubdub(i)=ub(i)*dubdr(i)
@@ -63,7 +63,7 @@ subroutine force()
      call complex_grad_1d( rv, ucp_old(:,j), ducpdr(:,j) )
      call complex_grad_1d( rv, vcp_old(:,j), dvcpdr(:,j) )
 
-     !-- ήη׻ (Τ)
+     !-- 移流項の計算 (線形項のみ)
 
      do i=1,nr
         updub(i,j)=ucp_old(i,j)*dubdr(i)
@@ -86,14 +86,14 @@ subroutine force()
         hbdhp(i,j)=hb(i)*dhcpdr(i,j)
      end do
 
-     !-- ꥪη׻
+     !-- コリオリ項の計算
 
      do i=1,nr
         corilu(i,j)=coril(i,j)*(ub(i)+ucp_old(i,j))
         corilv(i,j)=coril(i,j)*vcp_old(i,j)
      end do
 
-     !-- 쥤꡼ԥ󥰹η׻
+     !-- レイリーダンピング項の計算
 
      do i=1,nr
         eup(i,j)=-epsu(i)*ucp_old(i,j)
@@ -101,7 +101,7 @@ subroutine force()
         ehp(i,j)=-epsh(i)*hcp_old(i,j)
      end do
 
-     !-- ѷη׻
+     !-- 変形項の計算
 
      do i=1,nr
         ubup(i,j)=ub(i)*ucp_old(i,j)
@@ -118,11 +118,11 @@ subroutine force()
 !$omp end do
 !$omp end parallel
 
-  !-- ήη׻
-  !-- ιη׻˻֤뤿, flag Ƿ׻ʤʤ餹äȤФ.
+  !-- 非線形移流項の計算
+  !-- この項の計算は非常に時間がかかるため, flag で計算しないならすっとばす.
 
-  if(force_flag(5:5)=='o')then  ! 
-     !-- ɾ
+  if(force_flag(5:5)=='o')then  ! 非線形項
+     !-- 非線形評価係数を初期化
      call complex_init( fup )
      call complex_init( fvp )
      call complex_init( fhp )
@@ -165,22 +165,22 @@ subroutine force()
      call complex_init( fihpdup )
      call complex_init( fihpdvp )
 
-     !-- ڥȥѿѴˡѤγĥ֤
-     do i=2,nr-1  ! j=1 ̽
-        fup(i,1)=ucp_old(i,1)  ! ȾʬѴˡȾʬ
+     !-- スペクトル変数を変換法用の拡張配列へ置き換える
+     do i=2,nr-1  ! j=1 だけの特別処理
+        fup(i,1)=ucp_old(i,1)  ! 前方半分を変換法用配列の前方半分に
         fvp(i,1)=vcp_old(i,1)
         fhp(i,1)=hcp_old(i,1)
         fdupdr(i,1)=ducpdr(i,1)
         fdvpdr(i,1)=dvcpdr(i,1)
         fdhpdr(i,1)=dhcpdr(i,1)
-        fdupdt(i,1)=(0.0,0.0)  ! theta ʬˤĤȿϥ.
+        fdupdt(i,1)=(0.0,0.0)  ! theta 微分について波数ゼロはゼロ.
         fdvpdt(i,1)=(0.0,0.0)
         fdhpdt(i,1)=(0.0,0.0)
      end do
 
      do j=2,hnt+1
         do i=2,nr-1
-           fup(i,j)=ucp_old(i,j)  ! ȾʬѴˡȾʬ
+           fup(i,j)=ucp_old(i,j)  ! 前方半分を変換法用配列の前方半分に
            fvp(i,j)=vcp_old(i,j)
            fhp(i,j)=hcp_old(i,j)
 !           fdupdr(i,j)=ducpdr(i,j)
@@ -189,8 +189,8 @@ subroutine force()
            fdupdt(i,j)=img*real(j-1)*ucp_old(i,j)
            fdvpdt(i,j)=img*real(j-1)*vcp_old(i,j)
            fdhpdt(i,j)=img*real(j-1)*hcp_old(i,j)
-           fup(i,jnt-j+2)=conjg(ucp_old(i,j))   ! ȾʬѴˡ
-                          ! θȾȾʬ, ξüϤޤ
+           fup(i,jnt-j+2)=conjg(ucp_old(i,j))   ! 後方半分を変換法用
+                          ! 配列の後半半分に, いずれも両端始まりで
            fvp(i,jnt-j+2)=conjg(vcp_old(i,j))
            fhp(i,jnt-j+2)=conjg(hcp_old(i,j))
 !           fdupdr(i,jnt-j+2)=conjg(fdupdr(i,j))
@@ -202,7 +202,7 @@ subroutine force()
         end do
      end do
 
-     !-- ڥȥѿ¶֤֤
+     !-- スペクトル変数を実空間へ置き換える
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i)
      do i=2,nr-1
@@ -218,7 +218,7 @@ subroutine force()
   &                    prim_fact=pfact,  &
   &                    omega_fix=omega_bi(0:pfact(5)-1,0:pfact(5)-1),  &
   &                    omegan_fix=omega_ni(0:jnt-1,0:jnt-1) )
-! ʲ,  fr?p ưʬȤ뤳Ȥ FFT 򤹤.
+! 以下は, 先に fr?p で動径方向に微分をとることで FFT を回避する.
 !        call ffttp_1d( jnt, fdupdr(i,:), frdupdr(i,:), 'i', prim='o' )
 !        call ffttp_1d( jnt, fdvpdr(i,:), frdvpdr(i,:), 'i', prim='o' )
 !        call ffttp_1d( jnt, fdhpdr(i,:), frdhpdr(i,:), 'i', prim='o' )
@@ -238,11 +238,11 @@ subroutine force()
 !$omp end do
 !$omp end parallel
 
-     !-- 
-     !-- ѿ̾Ȥ, vpd?? Ϥ٤ theta ʬɽΤ,
-     !-- ѿȤƤ ik * ?? ȤǷ׻.
-     !-- , upd?? Ϥ٤ r ʬɽΤ, Τޤ޳ݤ.
-     !-- ʤ, theta ʬ 1/r ϳƹ׻ΤȤ˳ݤ
+     !-- 非線形
+     !-- 変数名として, vpd?? 型はすべて theta 方向の微分を表すので,
+     !-- 変数としては ik * ?? という形で計算される.
+     !-- 一方, upd?? はすべて r 方向の微分を表すので, そのまま掛けられる.
+     !-- なお, theta 方向の微分で生じる 1/r 係数は各項計算のときに掛けられる
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(j,i)
@@ -258,7 +258,7 @@ subroutine force()
            fvpdvp(i,j)=frvp(i,j)*frdvpdt(i,j)
            fvpdhp(i,j)=frvp(i,j)*frdhpdt(i,j)
            fhpdup(i,j)=frhp(i,j)*frdupdr(i,j)
-           fhpdvp(i,j)=frhp(i,j)*frdvpdt(i,j)  ! ι theta ʬʤ
+           fhpdvp(i,j)=frhp(i,j)*frdvpdt(i,j)  ! この項は theta 微分しかない
 !           fhpdhp(i,j)=frhp(i,j)*frdhpdr(i,j)
            fupvp(i,j)=frup(i,j)*frvp(i,j)
            fuphp(i,j)=frup(i,j)*frhp(i,j)
@@ -268,7 +268,7 @@ subroutine force()
 !$omp end do
 !$omp end parallel
 
-     !-- ڥȥ֤֤ľ
+     !-- スペクトル空間へ置き直す
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i)
@@ -321,7 +321,7 @@ subroutine force()
 !$omp end do
 !$omp end parallel
 
-     !-- ѴˡѴ줿ڥȥ force سǼ
+     !-- 変換法で変換された非線形スペクトル項を force に代入する配列へ格納
 
      do j=1,hnt+1
         do i=2,nr-1
@@ -345,11 +345,11 @@ subroutine force()
 !$omp do schedule(dynamic) private(i,j)
   do j=1,hnt+1
 
-!-- ƹ׻
-   !-- ؤޤȤ
-   !-- ΤȤ, j=1 ϼ¿ʬȿ, ʬȿ nt/2 ʤΤ,
-   !-- Ѥ˽ʬ.
-     if(force_flag(1:1)=='o')then  ! ή
+!-- 各項計算
+   !-- 強制項へまとめる
+   !-- このとき, j=1 は実数成分が波数ゼロ, 虚数成分が波数 nt/2 なので,
+   !-- それ用に処理を分ける.
+     if(force_flag(1:1)=='o')then  ! 線形移流項
 
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
@@ -370,7 +370,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(2:2)=='o')then  ! ꥪ
+     if(force_flag(2:2)=='o')then  ! コリオリ項
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
   &                    +corilv(i,j)
@@ -379,7 +379,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(3:3)=='o')then  ! Ȼ
+     if(force_flag(3:3)=='o')then  ! 拡散項
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
   &                    -diff_t*(real(j-1))**2*ucp_old(i,j)/rv(i)/rv(i)  &
@@ -399,7 +399,7 @@ subroutine force()
         end do
      end if
  
-     if(force_flag(4:4)=='o')then  ! 쥤꡼ԥ󥰹
+     if(force_flag(4:4)=='o')then  ! レイリーダンピング項
 
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
@@ -411,7 +411,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(5:5)=='o')then  ! ή
+     if(force_flag(5:5)=='o')then  ! 非線形移流項
 
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
@@ -426,7 +426,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(6:6)=='o')then  ! Ϲ
+     if(force_flag(6:6)=='o')then  ! 遠心力項
 
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
@@ -440,7 +440,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(7:7)=='o')then  ! Ϣ³μȯ
+     if(force_flag(7:7)=='o')then  ! 連続の式の発散項
 
         do i=2,nr-1
            forceh(i,j)=forceh(i,j)  &
@@ -456,7 +456,7 @@ subroutine force()
         end do
      end if
 
-     if(force_flag(8:8)=='o')then  ! Ϸٹ
+     if(force_flag(8:8)=='o')then  ! 圧力傾度項
         do i=2,nr-1
            forceu(i,j)=forceu(i,j)  &
   &                    -(dhcpdr(i,j))
