@@ -1,5 +1,5 @@
 program solver
-! Nolan and Montgomery 2001 ǥ
+! Nolan and Montgomery 2001 の浅水モデル
   use gtool_history
   use Derivation
   use ffts
@@ -16,10 +16,10 @@ program solver
 
   implicit none
 
-!-- do loop ѿ
+!-- do loop 用変数の定義
   integer :: i, j, it
 
-!-- namelist ɤ߹
+!-- namelist の読み込み
 
   call read_name()
 
@@ -61,7 +61,7 @@ program solver
 
   call val_allocate()
 
-!-- Ͳ (2d ǡ 3 ǡؤγĥ)
+!-- 初期値化 (2d データから 3 次元データへの拡張)
 
   do i=1,nr
      ub(i)=0.0
@@ -71,14 +71,14 @@ write(*,*) "starting initialization."
   call HistoryGet( trim(finame), 'hbar', hib )
   call HistoryGet( trim(finame), 'r', ri )
 
-!-- ʻκ
+!-- 格子点の再定義
   call val_coordinate()
 
-!-- bar Ⱦʻؤ
+!-- bar の半格子点への内挿
   call auto_interpolation_1d( ri, rv, vib, vb )
   call auto_interpolation_1d( ri, rs, hib, hb )
 
-!-- 쥤꡼ԥ
+!-- レイリーダンピング設定
   epsu=0.0
   epsv=0.0
   epsh=0.0
@@ -91,7 +91,7 @@ write(*,*) "starting initialization."
      end if
   end do
 
-!-- ͺ
+!-- 初期値作成
 
   do j=1,ntheta
      do i=1,nr
@@ -110,7 +110,7 @@ write(*,*) "starting initialization."
 
   write(*,*) "normally pass the initialization."
 
-!-- ϥեν
+!-- 出力ファイルの初期化
   call HistoryCreate( file=trim(foname), title='shallow result data', &
   & source='test', institution='test', dims=(/'r    ','theta', 't    '/),  &
   & dimsizes=(/nr,ntheta, 0/),  & 
@@ -131,7 +131,7 @@ write(*,*) "starting initialization."
 
   write(*,*) "time integration start."
 
-  !-- ν (ͤν)
+  !-- 出力等の処理 (初期値の出力)
   do j=1,ntheta
      do i=1,nr
         ucp_old(i,j)=urp_dmp(i,j)
@@ -167,17 +167,17 @@ write(*,*) "starting initialization."
 !$omp end do
 !$omp end parallel
 
-!-- solver 
+!-- solver スタート
 
   do it=1,nt
 
      call time_schematic( it )
 
-  !-- ƥåפοʤ߶
+  !-- ステップの進み具合出力
      write(*,*) "This step is ", it, "(time =", real(it)*dt, "[s])."
 
-     !-- ν (2)
-     if(mod(it,dmpstp)==0)then  ! ѴԤ¿Ϥ.
+     !-- 出力等の処理 (2)
+     if(mod(it,dmpstp)==0)then  ! 逆変換を行い実数出力する.
 
 !$omp parallel default(shared)
 !$omp do schedule(dynamic) private(i,j)
@@ -215,7 +215,7 @@ write(*,*) "starting initialization."
 
   end do
 
-!-- solver ȥå
+!-- solver ストップ
 
   write(*,*) "solver is normally."
 
