@@ -1,8 +1,8 @@
 program initial_make
-!  ǥη׻ɬפʽͥեץ
-!  ɬפ˱ƥν񤭴ǽ.
-!  ɤ߹ॵǥ󥰤ǱľʻҤꤹ.
-!  ɱοʣ֤.
+!  モデルの計算に必要な初期値ファイルを生成するプログラム
+!  必要に応じてソースの書き換えが可能.
+!  読み込むサウンディングで鉛直格子を決定する.
+!  壁雲の数を複数設置する.
   use file_operate
   use Thermo_Const
   use Math_Const
@@ -24,59 +24,59 @@ program initial_make
   real :: dr, dz
   character(4) :: bc
   character(80) :: fname
-  character(80) :: sound_name  ! ǥ󥰥ե̾
+  character(80) :: sound_name  ! サウンディングファイルの名前
 
 !-- internal valiables
   integer :: i, j
-  real, allocatable, dimension(:) :: r, z, zd  ! о 2 ư, ľɸ
-  real, allocatable, dimension(:) :: rm, vm  ! ƹ٤Ǥκ® MWR
+  real, allocatable, dimension(:) :: r, z, zd  ! 軸対称 2 次元の動径, 鉛直座標
+  real, allocatable, dimension(:) :: rm, vm  ! 各高度での最大風速と MWR
   real, allocatable, dimension(:) :: r1, r2  ! inner, outer core boundary
-  real, allocatable, dimension(:) :: pres_s, temp_s, pt_s, rho_s  ! ǥ
-  real, allocatable, dimension(:,:) :: v0, pres, qv  ! , , ǮΨ
-  real, allocatable, dimension(:,:) :: mom  ! ư̥
-  real, allocatable, dimension(:,:) :: theta0, rho  ! β, ̩
-  real, allocatable, dimension(:,:) :: x  ! ɸѿ
-  real, allocatable, dimension(:,:) :: coriol  ! ꥪѥ᡼
-  real, allocatable, dimension(:,:) :: N2  ! Ͽư **2
+  real, allocatable, dimension(:) :: pres_s, temp_s, pt_s, rho_s  ! サウンディング
+  real, allocatable, dimension(:,:) :: v0, pres, qv  ! 初期の接線風, 気圧, 加熱率
+  real, allocatable, dimension(:,:) :: mom  ! 運動量ソース
+  real, allocatable, dimension(:,:) :: theta0, rho  ! 初期の温位, 密度
+  real, allocatable, dimension(:,:) :: x  ! 座標変数
+  real, allocatable, dimension(:,:) :: coriol  ! コリオリパラメータ
+  real, allocatable, dimension(:,:) :: N2  ! 浮力振動数 **2
   character(20), allocatable :: val(:,:)
   real :: nibun_left, nibun_right, func_left, func_right
   real :: err, max_val
   real, allocatable, dimension(:) :: ac
 
 !-- constant value
-  integer, parameter :: sline=2  ! ǥ󥰥եɤФ
-  integer, parameter :: n=1  ! eye Ǥ®٤η
-  integer, parameter :: m_bell=2  ! ǮǮΥ٥ؿμ
+  integer, parameter :: sline=2  ! サウンディングファイルの読み飛ばし行
+  integer, parameter :: n=1  ! eye での速度の傾き
+  integer, parameter :: m_bell=2  ! 非断熱加熱のベル関数の次数
   real, parameter :: x1=300.0e3
-  real, parameter :: r_qv=-2.0e3   ! qv  rm εΥ
-  real, parameter :: dRm=16.0/18.0  ! Rmax η (dr/dz)
-  real, parameter :: rmax=50.0e3  ! ɽ̤Ǥ Rmax
-  real, parameter :: vmax=50.0  ! ɽ̤Ǥ Vmax
-  real, parameter :: z_v0=18.0e3  ! vmax ˤʤ (ɽ餳ޤ˸)
-  real, parameter :: z_qv=18.0e3  ! qv ˤʤ
-  real, parameter :: dr12=20.0e3  ! r1  r2 εΥ
-  real, parameter :: err_max=1.0e-5  ! ʬˡμ«
+  real, parameter :: r_qv=-2.0e3   ! qv と rm の距離
+  real, parameter :: dRm=16.0/18.0  ! Rmax の傾き (dr/dz)
+  real, parameter :: rmax=50.0e3  ! 地表面での Rmax
+  real, parameter :: vmax=50.0  ! 地表面での Vmax
+  real, parameter :: z_v0=18.0e3  ! vmax がゼロになる高度 (地表からここまで線形に減少する)
+  real, parameter :: z_qv=18.0e3  ! qv がゼロになる高度
+  real, parameter :: dr12=20.0e3  ! r1 と r2 の距離
+  real, parameter :: err_max=1.0e-5  ! 二分法の収束条件
 
-!-- ¿ɱξ
-  real, allocatable, dimension(:) :: rm2, vm2  ! ƹ٤Ǥκ® MWR
-  real, parameter :: dRm2=128.0/18.0  ! Rmax η (dr/dz)
-  real, parameter :: rmax2=100.0e3  ! ɽ̤Ǥ Rmax
-  real, parameter :: vmax2=50.0  ! ɽ̤Ǥ Vmax
-  real, parameter :: dr122=40.0e3  ! r1  r2 εΥ
+!-- 多重壁雲の場合
+  real, allocatable, dimension(:) :: rm2, vm2  ! 各高度での最大風速と MWR
+  real, parameter :: dRm2=128.0/18.0  ! Rmax の傾き (dr/dz)
+  real, parameter :: rmax2=100.0e3  ! 地表面での Rmax
+  real, parameter :: vmax2=50.0  ! 地表面での Vmax
+  real, parameter :: dr122=40.0e3  ! r1 と r2 の距離
   real, allocatable, dimension(:) :: r12, r22  ! inner, outer core boundary
-  real, allocatable, dimension(:,:) :: x2  ! ɸѿ
+  real, allocatable, dimension(:,:) :: x2  ! 座標変数
 
 !-- function name
   real :: func_a, Bell
 
-!-- namelist Υѥ᡼
+!-- namelist からのパラメータの代入
   namelist /input /nr, nz, dr, dz, bc, fname, sound_name, coril, mom_flag
   read(5,nml=input)
 
-!-- γ
+!-- 配列の割付
   allocate(r(nr))
   allocate(z(nz))
-  allocate(zd(nz))  ! ǮǮʬ۷׻Ѥ.
+  allocate(zd(nz))  ! 非断熱加熱の分布計算で用いる.
   allocate(rm(nz))
   allocate(vm(nz))
   allocate(r1(nz))
@@ -103,10 +103,10 @@ program initial_make
   allocate(x2(nr,nz))
 
   coriol=2.0*omega*sin(coril*pi/180.0)
-  mom=0.0  ! ߤΤȤ, ư̥ initial_make Ǥۤ˺ʤ.
+  mom=0.0  ! 現在のところ, 運動量ソースは initial_make では陽に作成しない.
 
-!-- ǥ󥰤ܾǮϳѿľɸ.
-!-- ǥ󥰤Υǡ namelist ꤵƤΤƱ.
+!-- サウンディングから基本場の熱力学変数・鉛直座標を設定.
+!-- サウンディングのデータ数は namelist で設定されているのと同じ値.
 
   call read_file_text( trim(sound_name), 4, nz, val, skip=sline )
 
@@ -119,10 +119,10 @@ program initial_make
 write(*,*) rho_s(i)
   end do
 
-!-- ɸͤ
+!-- 座標値の設定
   r=(/(dr*real(i-1),i=1,nr)/)
 
-!-- ɬפʥѥ᡼
+!-- 傾度風場の生成に必要なパラメータの設定
   rm(1)=rmax
   vm(1)=vmax
   rm2(1)=rmax2
@@ -140,10 +140,10 @@ write(*,*) rho_s(i)
 !     vm(j)=vm(1)*func_a((z_v0-z(j))/z_v0)
   end do
 
-!-- r1, r2 η (Willoughby 2006)
+!-- r1, r2 の決定 (Willoughby 2006)
   do j=1,nz
      ac(j)=(real(n)*x1)/(real(n)*x1+rm(j))
-!-- r1 뤿, ͤ 0, 1 Ȥʬˡ
+!-- r1 を求めるため, 初期値を 0, 1 とした二分法開始
      nibun_left=0.0
      nibun_right=1.0
      func_left=func_a(nibun_left)-ac(j)
@@ -170,7 +170,7 @@ write(*,*) rho_s(i)
 
   do j=1,nz
      ac(j)=(real(n)*x1)/(real(n)*x1+rm2(j))
-!-- r1 뤿, ͤ 0, 1 Ȥʬˡ
+!-- r1 を求めるため, 初期値を 0, 1 とした二分法開始
      nibun_left=0.0
      nibun_right=1.0
      func_left=func_a(nibun_left)-ac(j)
@@ -196,8 +196,8 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
      end do
   end do
 
-!-- ͤ
-!-- 
+!-- 初期値の生成
+!-- 傾度風場の生成
   do j=1,nz
      do i=1,nr
         if(r(i)<=r1(j))then
@@ -221,11 +221,11 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
      end do
   end do
 
-!-- ǥ󥰤ȼоήϳءʿվ.
+!-- サウンディングと軸対称流から静力学・傾度風平衡場の生成.
 
   call hydro_grad_eqb( r, z, coriol, v0, pres_s, rho_s, pres, rho )
 
-!-- Фɬפ pt ׻
+!-- ソルバに必要な pt を計算
 
   do j=1,nz
      do i=1,nr
@@ -233,8 +233,8 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
      end do
   end do
 
-!-- ǮΨη׻
-!-- Ͽưη׻
+!-- 加熱率の計算
+!-- 浮力振動数の計算
   do i=1,nr
      call grad_1d( z, theta0(i,:), N2(i,:) )
      do j=1,nz
@@ -242,10 +242,10 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
      end do
   end do
 
-!  call max_val_2d( N2, maxnx, maxny, max_val )  ! ͤŬѹ
+!  call max_val_2d( N2, maxnx, maxny, max_val )  ! この値は適宜変更
   max_val=1.5e-4
 
-!-- zd 
+!-- zd の設定
   zd=(/(((z_qv-z(j))/(z_qv-5.0e3)),j=1,nz)/)
 
   do j=1,nz
@@ -256,16 +256,16 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
   end do
 
 
-!-- եؤν񤭹
+!-- 初期ファイルへの書き込み
 
-!-- ʲ GrADS 
+!-- 以下は GrADS 形式
 !  call write_file( trim(fname), nr, nz, 1, v0 )
 !  call write_file( trim(fname), nr, nz, 2, pres, mode='old' )
 !  call write_file( trim(fname), nr, nz, 3, theta0, mode='old' )
 !  call write_file( trim(fname), nr, nz, 4, rho, mode='old' )
 !  call write_file( trim(fname), nr, nz, 5, qv, mode='old' )
 
-!-- ʲ netcdf 
+!-- 以下は netcdf 形式
   call HistoryCreate( file=trim(fname), title='SEQ initial data', &
     & source='test', institution='test', dims=(/'r','z'/), dimsizes=(/nr,nz/),  &
     & longnames=(/'r-coordinate','z-coordinate'/),  &
@@ -306,7 +306,7 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
 
   call HistoryClose
 
-!-- λΤΤ餻
+!-- 終了のお知らせ
 
   write(*,*) "initial_make is normally conplete."
 
@@ -315,7 +315,7 @@ end program
 
 real function func_a( val )
   implicit none
-  real, intent(in) :: val  ! ɸѿ
+  real, intent(in) :: val  ! 座標変数
 
   if(val<=0.0)then
      func_a=0.0
@@ -335,10 +335,10 @@ end function
 
 
 real function Bell( n, val )
-!  Willoughby 2006 󾧤줿٥뷿ؿ׻.
+!  Willoughby 2006 で提唱されたベル型関数を計算する.
   implicit none
-  integer, intent(in) :: n  ! 
-  real, intent(in) :: val  ! 
+  integer, intent(in) :: n  ! 次数
+  real, intent(in) :: val  ! 引数
 
   if(val>=0.0.and.val<=1.0)then
      Bell=(2.0**(2*n))*((val*(1.0-val))**n)
