@@ -20,12 +20,12 @@ subroutine val_coordinate()
 
   integer :: i
 
-!-- ƺɸ¤
+!-- 各座標径の設定
 
   rs=(/((rmin+(real(i-1))*dr),i=1,nr+3)/)
-  zs=(/((zmin-(real(i-1))*dz),i=1,nz+3)/)    ! ϺɸʤΤ, ۤ㤤
+  zs=(/((zmin-(real(i-1))*dz),i=1,nz+3)/)    ! 圧力座標なので, 上ほど低い
   rv=(/((rmin+(real(i)-0.5)*dr),i=1,nr+3)/)
-  zv=(/((zmin-(real(i)-0.5)*dr),i=1,nz+3)/)  ! ϺɸʤΤ, ۤ㤤
+  zv=(/((zmin-(real(i)-0.5)*dr),i=1,nz+3)/)  ! 圧力座標なので, 上ほど低い
   theta=(/(((real(i-1))*2.0*pi/real(ntheta-1)),i=1,ntheta)/)
 
 end subroutine
