@@ -1,6 +1,6 @@
 program adjust
-! ϹĴǥǸڤץ
-! 1 ǥ
+! 地衡風調節を浅水系線形モデルで検証するプログラム
+! 1 次元モデル
 
   use file_operate
   use Derivation
@@ -28,7 +28,7 @@ program adjust
   real, allocatable, dimension(:) :: h, u, v
   real, allocatable, dimension(:) :: dhdx, dudx, dvdx
   real, allocatable, dimension(:) :: dh2dx, du2dx, dv2dx
-  real, allocatable, dimension(:) :: dheightx
+  real, allocatable, dimension(:) :: dheightx, bound_sp
   real, allocatable, dimension(:,:) :: dval_h, dval_u, dval_v
   real, allocatable, dimension(:,:) :: dval_pe, dval_ke, dval_ae
   real, allocatable, dimension(:,:) :: dmp_tmp
@@ -78,6 +78,7 @@ program adjust
   allocate(u(nx))
   allocate(v(nx))
   allocate(dx(nx))
+  allocate(bound_sp(nx))
   allocate(dval_h(nx,dn))
   allocate(dval_u(nx,dn))
   allocate(dval_v(nx,dn))
@@ -121,6 +122,13 @@ program adjust
   write(*,*) "phase speed is ", cp, "m/s."
   write(*,*) "deformation radius is ", lambda, "m."
 
+  if(bound==4)then   ! setting lateral sponge layer
+     bound_sp=0.0
+     bound_sp(1)=0.25/(ini_x(10)/cp)  ! inverse of e-folding time for 10 grids
+     bound_sp(2:10)=bound_sp(1)
+     bound_sp(nx-9:nx)=bound_sp(1)
+  end if
+
 !-- calculating fluid depth gradient.
 !-- (because of constant for time except non-linear.)
 !-- base state wind is assumed steady.
@@ -248,6 +256,12 @@ program adjust
            force_u(i)=force_u(i)-tau*old_u(i)
            force_v(i)=force_v(i)-tau*old_v(i)
         end if
+
+        if(bound==4)then
+           force_h(i)=force_h(i)-bound_sp(i)*(old_h(i)-ini_h(i))
+           force_u(i)=force_u(i)-bound_sp(i)*(old_u(i)-ini_u(i))
+           force_v(i)=force_v(i)-bound_sp(i)*(old_v(i)-ini_v(i))
+        end if
      end do
 
   ! time integration
@@ -269,7 +283,7 @@ program adjust
   ! boundary coditions
 
      select case (bound)
-     case (1)
+     case (1,4)
         h(1)=h(2)
         u(1)=u(2)
         v(1)=v(2)
