@@ -1,23 +1,23 @@
 program advection
-  use ffts  ! FFT 롼
-  use file_operate  ! ̥ե
+  use ffts  ! FFT ルーチン
+  use file_operate  ! 結果ファイル出力
   use Math_Const
   use gtool_history
   implicit none
-  integer :: nx  ! x ȿ
-  real :: dt  ! ׻ֳִ
-  integer :: nt  ! ׻ƥå׿
-  real :: xmin  ! x ɸü
-  real :: dx  ! x ɸʻҴֳ
+  integer :: nx  ! x 方向の切断波数
+  real :: dt  ! 計算時間間隔
+  integer :: nt  ! 計算ステップ数
+  real :: xmin  ! x 座標左端
+  real :: dx  ! x 座標格子間隔
   real :: Lx  ! domain
   real :: coe
   integer :: j, k
-  real, allocatable, dimension(:) :: x  ! x ɸ
-  real, allocatable, dimension(:) :: y  ! 顼ѿ
-  real, allocatable, dimension(:) :: time  ! 
-  complex, allocatable, dimension(:) :: fm1  ! ڥȥ
-  complex, allocatable, dimension(:) :: fm2  ! ڥȥ
-  complex, allocatable, dimension(:) :: fm_tmp  ! ׽
+  real, allocatable, dimension(:) :: x  ! x 座標
+  real, allocatable, dimension(:) :: y  ! スカラー変数
+  real, allocatable, dimension(:) :: time  ! 時間
+  complex, allocatable, dimension(:) :: fm1  ! スペクトル用
+  complex, allocatable, dimension(:) :: fm2  ! スペクトル用
+  complex, allocatable, dimension(:) :: fm_tmp  ! ダンプ出力用
   complex, parameter :: i=(0.0,1.0)
 
   namelist /input /nx,dt,nt,xmin,dx
@@ -52,7 +52,7 @@ program advection
 
 !-- gtool history (netcdf dump)
 
-  call HistoryCreate( &                             ! ҥȥ꡼
+  call HistoryCreate( &                             ! ヒストリー作成
     & file='advection.nc', title='spectral advecting model', &
     & source='Sample program of gtool_history/gtool5',   &
     & institution='GFD_Dennou Club davis project',       &
@@ -61,33 +61,33 @@ program advection
     & units=(/'m','s'/),                                 &
     & origin=0.0, interval=real(nt*dt) )
 
-  call HistoryPut( 'x', x )                            ! ѿ
+  call HistoryPut( 'x', x )                            ! 次元変数出力
 
-  call HistoryAddVariable( &                           ! ѿ
+  call HistoryAddVariable( &                           ! 変数定義
     & varname='amp', dims=(/'x','t'/), &
     & longname='amplitude', units='1', xtype='float')
 
-!-- ʬ
+!-- 時間積分開始
   do j=1,nt
-!-- CR ˡǻʬ
+!-- CR 法で時間積分
      fm2(0)=fm1(0)
      do k=1,nx
         fm2(k)=((1.0-2.0*i*coe*real(k)-(coe*real(k))**2)/  &
   &            (1.0+(coe*real(k))**2))*fm1(k)
-        fm1(k)=fm2(k)  ! ƥåפϤ
+        fm1(k)=fm2(k)  ! 次ステップへ渡す
      end do
 
      do k=1,nx
-        fm2(nx+k)=conjg(fm2(nx-k+1))  ! ׻פ˷̤Ϥ
+        fm2(nx+k)=conjg(fm2(nx-k+1))  ! 計算不要な配列に結果を渡す
      end do
 
      call ffttp_1d( 2*nx+1, fm2, fm_tmp, 'i', 'o' )
 
-     do k=0,2*nx  ! ¿ؤѴ
+     do k=0,2*nx  ! 実数への変換
         y(k)=real(fm_tmp(k))
      end do
 
-     call HistoryPut( 'amp', y(0:2*nx) )                         ! ѿ
+     call HistoryPut( 'amp', y(0:2*nx) )                         ! 変数出力
 
   end do
 
