@@ -12,7 +12,8 @@ program cloud_1d
   implicit none
 
   integer :: i, j, k, nmax, nt, dmpstp
-  real, parameter :: zmax=2500.0   ! vertical wind maximum height.
+  integer, parameter :: ln=2
+  real, parameter :: zmax=5000.0   ! vertical wind maximum height.
   real, parameter :: wfact=0.5   ! vertical wind maximum height.
   real :: dt, rho0
   real :: VDvr_term, NUAvi_term, VDvi_term, VDvs_term, VDvg_term
@@ -487,10 +488,10 @@ program cloud_1d
 
         do j=2,nmax-1
            if(tmp_qv(j)>0.0.or.tmp_qi(j)>0.0)then
-              call Moist_Sature_Adjust_Ice( pres(j), tmp_pt(j), tmp_qv(j), tmp_qi(j) )
+              call Moist_Sature_Adjust_Ice( pres(j), tmp_pt(j), tmp_qv(j), tmp_qi(j), ln=ln )
            end if
            if(tmp_qv(j)>0.0.or.tmp_qc(j)>0.0)then
-              call Moist_Sature_Adjust( pres(j), tmp_pt(j), tmp_qv(j), tmp_qc(j) )
+              call Moist_Sature_Adjust( pres(j), tmp_pt(j), tmp_qv(j), tmp_qc(j), ln=ln )
            end if
         end do
 
@@ -580,12 +581,12 @@ program cloud_1d
            if(tmp_qv(j)>=0.0.and.tmp_qi(j)>=0.0)then
               if((tmp_qv(j)/=0.0.or.tmp_qi(j)/=0.0)  &
   &              .and.(temp(j)<tscp))then
-                 call Moist_Sature_Adjust_Ice( pres(j), tmp_pt(j), tmp_qv(j), tmp_qi(j) )
+                 call Moist_Sature_Adjust_Ice( pres(j), tmp_pt(j), tmp_qv(j), tmp_qi(j), ln=ln )
               end if
            end if
            if(tmp_qv(j)>=0.0.and.tmp_qc(j)>=0.0)then
               if((tmp_qv(j)/=0.0.or.tmp_qc(j)/=0.0))then
-                 call Moist_Sature_Adjust( pres(j), tmp_pt(j), tmp_qv(j), tmp_qc(j) )
+                 call Moist_Sature_Adjust( pres(j), tmp_pt(j), tmp_qv(j), tmp_qc(j), ln=ln )
               end if
            end if
         end do
