@@ -2,12 +2,26 @@ require "numru/netcdf"
 include NumRu
 include NMath
 
+# perturbations of vx, vy are given as vt (azimuthal velocity).
+# V = vx*ex+vy*ey = vr*er+vt*et
+# Now, vr is zero, so V = vt*et
+# let be k vertical unit vector, et = er x k.
+# let be R vector of position, er = R/|R|.
+# So, V = (vt/|R|) * (R x k).
+# Where R = x*ex+y*ey.
+# Thus, V = (vt/|R|) * ( (x*ex+y*ey) x k ) = (vt/|R|) * (y*ex-x*ey)
+# Therefore, vx = C*y, vy = -C*x, where C = vt/|R|
+
 nx = 100
 ny = 100
 fname = 'init.dat'
 mean_height = 0.0
-meanu_flow = 10.0
+meanu_flow = 0.0
 meanv_flow = 0.0
+pert_height = 0.0
+pertu_flow = 1.0
+pertv_flow = 1.0
+pertvr_max = 0.1   # RMW = (inix[nx]-inix[1])*pertvr_max
 
 inix = NArray.sfloat(nx).indgen(0.0)
 tmpx = inix[nx/2]
@@ -24,22 +38,40 @@ end
 hei = NArray.sfloat(nx,ny)
 ubar = NArray.sfloat(nx,ny)
 vbar = NArray.sfloat(nx,ny)
-ini = NArray.sfloat(nx,ny)
-ini_tmp = NArray.sfloat(nx,ny)
+ini_h = NArray.sfloat(nx,ny)
+ini_u = NArray.sfloat(nx,ny)
+ini_v = NArray.sfloat(nx,ny)
+
+tmpr = 0.0
+tmpt = 0.0
+tmpva = 0.0
+pert_rmw = (inix[nx-1]-inix[0])*pertvr_max
+pertva = sqrt(pertu_flow**2+pertv_flow**2)
 
 hei[0..nx-1,0..ny-1] = 0.0
-ini[0..nx-1,0..ny-1] = 0.0
-ini_tmp[0..nx-1,0..ny-1] = 0.0
+ini_h[0..nx-1,0..ny-1] = 0.0
+ini_u[0..nx-1,0..ny-1] = 0.0
+ini_v[0..nx-1,0..ny-1] = 0.0
 
 for j in 0..ny-1
    for i in 0..nx-1
 #      if (((inix[i]-inix[nx/2])**2+(iniy[j]-iniy[ny/2])**2)**0.5<10.0*nx) then
 #         ini[i,j] = 1.0
 #      end
-##      ini[i,j]=exp(-0.01*((inix[i]/nx)**2+(iniy[j]/ny)**2))
-      ini[i,j]=0.0
-      hei[i,j]=mean_height+10.0*sin(4.0*PI*inix[i]/((inix[nx-1]-inix[0])))*sin(4.0*PI*iniy[j]/((iniy[ny-1]-iniy[0])))
+      ini_h[i,j]=pert_height*exp(-0.01*((inix[i]/nx)**2+(iniy[j]/ny)**2))
+#      ini_u[i,j]=pertu_flow*exp(-0.01*((inix[i]/nx)**2+(iniy[j]/ny)**2))
+#      ini_v[i,j]=pertv_flow*exp(-0.01*((inix[i]/nx)**2+(iniy[j]/ny)**2))
+      tmpr = sqrt((inix[i]-inix[nx/2])**2+(iniy[j]-iniy[ny/2])**2)
+      tmpva = pertva*exp(-0.01*((tmpr-pert_rmw)/nx)**2)
+      if (tmpr == 0.0)  then
+         ini_u[i,j] = 0.0
+         ini_v[i,j] = 0.0
+      else
+         ini_u[i,j] = tmpva*iniy[j]/tmpr
+         ini_v[i,j] = -tmpva*inix[i]/tmpr
+      end
 #      hei[i,j]=mean_height+10.0*exp(-0.25*((inix[i]/nx)**2+(iniy[j]/ny)**2))
+      hei[i,j]=mean_height
       ubar[i,j]=meanu_flow
       vbar[i,j]=meanv_flow
    end
@@ -54,7 +86,7 @@ x = f.def_var('x','sfloat',['x'])
 y = f.def_var('y','sfloat',['y'])
 
 h = f.def_var('h','sfloat',['x','y'])
-h.put_att('long_name','height')
+h.put_att('long_name','surface height')
 h.put_att('units','m')
 ht = f.def_var('ht','sfloat',['x','y'])
 ht.put_att('long_name','height')
@@ -75,11 +107,11 @@ f.enddef
 
 x.put(inix)
 y.put(iniy)
-h.put(ini)
+h.put(ini_h)
 ht.put(hei)
 ub.put(ubar)
 vb.put(vbar)
-val1.put(ini_tmp)
-val2.put(ini_tmp)
+val1.put(ini_u)
+val2.put(ini_v)
 
 f.close
