@@ -1,7 +1,7 @@
 program sound_1d
-! 饸ιصݴ¬ǡ, 1 Υץեǡ
-! , ٤ˤѡˤ CAPE Υѥ᡼׻.
-! ǥǡΥեޥåȤϥƥȷΤߥݡ
+! ラジオゾンデ等の高層気象観測データから, 1 次元のプロファイルデータ
+! および, 指定高度におけるパーセルを基にした CAPE 等のパラメータを計算する.
+! ゾンデデータのフォーマットはテキスト形式のみサポート
 
   use Thermo_Const
   use Thermo_Function
@@ -15,64 +15,68 @@ program sound_1d
 
   implicit none
 
-  real, allocatable, dimension(:) :: temp    ! 
-  real, allocatable, dimension(:) :: height  ! 
-  real, allocatable, dimension(:) :: pres    ! 
-  real, allocatable, dimension(:) :: rh      ! м
-  real, allocatable, dimension(:) :: qv      ! 
-  real, allocatable, dimension(:) :: pt      ! 
-  real, allocatable, dimension(:) :: ept     ! 
-  real, allocatable, dimension(:) :: sept    ! ˰
-  real, allocatable, dimension(:) :: ew      ! 
-  real, allocatable, dimension(:) :: ww      ! 
-  real, allocatable, dimension(:) :: tmp     ! ƥݥ
+  real, allocatable, dimension(:) :: temp    ! 温度
+  real, allocatable, dimension(:) :: height  ! 高度
+  real, allocatable, dimension(:) :: pres    ! 気圧
+  real, allocatable, dimension(:) :: rh      ! 相対湿度
+  real, allocatable, dimension(:) :: qv      ! 混合比
+  real, allocatable, dimension(:) :: pt      ! 温位
+  real, allocatable, dimension(:) :: ept     ! 相当温位
+  real, allocatable, dimension(:) :: sept    ! 飽和相当温位
+  real, allocatable, dimension(:) :: ew      ! 東西風
+  real, allocatable, dimension(:) :: ww      ! 南北風
+  real, allocatable, dimension(:) :: tmp     ! テンポラリ配列
+  real, allocatable, dimension(:) :: p_height! 静力学高度
+  real, allocatable, dimension(:) :: temp_v  ! 仮温度
   real, allocatable, dimension(:,:) :: draw_tate, draw_yoko, write_data
-  real, dimension(11) :: col_lev  ! ۥɥչ
-  real :: height_lcl, pres_lcl  ! LCL 
-  real :: height_lfc, pres_lfc  ! LFC 
-  real :: height_lnb, pres_lnb  ! LNB 
+  real, dimension(11) :: col_lev  ! ホドグラフ高度用
+  real :: height_lcl, pres_lcl  ! LCL 高度
+  real :: height_lfc, pres_lfc  ! LFC 高度
+  real :: height_lnb, pres_lnb  ! LNB 高度
   real :: cape_c  ! CAPE
   real :: cin_c  ! CIN
-  real :: precip  ! Ĺ߿
-  real :: z_ref  ! CAPE η׻κ, .
-  real :: p_ref  ! CAPE η׻κ, ൤.
-  real :: unit_v  ! ñ̥٥ȥ礭.
-  real, dimension(2) :: draw_region_p, draw_region_z
+  real :: precip  ! 可降水量
+  real :: z_ref  ! CAPE 等の計算の際, 基準高度.
+  real :: p_ref  ! CAPE 等の計算の際, 基準気圧.
+  real :: unit_v  ! 単位ベクトルの大きさ.
+  real :: diff_ref  ! draw_flag(6:6) のとき, 真値とする高度 [Pa or m]
+  real, dimension(2) :: draw_region_p, draw_region_z, draw_region_t
   real, dimension(2) :: vx_new, vy_new
   real, dimension(6), parameter :: convx=(/0.3, 0.5, 0.55, 0.75, 0.55, 0.75/),  &
                                    convy=(/0.5, 0.8, 0.5, 0.8, 0.5, 0.8/)
   real, allocatable, dimension(:,:) :: cvx, cvy
 
-  integer :: i, j, k, l, m, n, iz, jmax, idz_min, idz_max
-  integer :: nz  ! 
-  integer :: nnz  ! ǡޤȤ˻Ȥΰˤ
-  integer :: nx  ! ǡο
+  integer :: i, j, k, l, m, n, iz, jmax, idz_min, idz_max, i_height, i_nz
+  integer :: nz  ! 高度方向の配列
+  integer :: nnz  ! データがまともに使える領域における配列数
+  integer :: nx  ! データカラムの数
   integer :: IWS
-  integer :: cape_opt  ! CAPE ׻κ, LNB ǡüξ.
-  integer, parameter :: fig_num=3  ! ޤμ
-  integer, dimension(11) :: col_num  ! ۥɥչ
+  integer :: cape_opt  ! CAPE 計算の際, LNB がデータ上端より上の場合の措置.
+  integer, parameter :: fig_num=3  ! 描く図の種類
+  integer, dimension(11) :: col_num  ! ホドグラフ高度用
 
-  character(1000), allocatable, dimension(:,:) :: fname  ! ǡե̾
-  character(1000) :: list_name  ! ǡꥹȥե̾
-  character(1000), allocatable, dimension(:,:) :: cval  ! ǡɤ߹
+  character(1000), allocatable, dimension(:,:) :: fname  ! データファイル名
+  character(1000) :: list_name  ! データリストファイル名
+  character(1000), allocatable, dimension(:,:) :: cval  ! データ読み込み用
   character(1000) :: tmp_char
-  character(5) :: draw_flag  ! ޤ˴ؤե饰
+  character(6) :: draw_flag  ! 作成図に関するフラグ
+  character(1) :: diff_typ  ! diff_ref の座標 'p' or 'z'
   character(10) :: t_c
   character(28) :: skew_c
   character(12), allocatable, dimension(:) :: title_c, title_u
   character(1) :: refer_flag
   character(70) :: sysfont
 
-  logical :: dmp_flag, no_draw_flag
+  logical :: dmp_flag, no_draw_flag, septlopt
 
   real :: undef
   integer, parameter :: skip_num=2
 
-!-- namelist file ɤ߹
+!-- namelist file 読み込み部
 
   namelist /input /z_ref, p_ref, cape_opt, list_name, dmp_flag, undef,  &
-  &                draw_flag, draw_region_p, draw_region_z, IWS, unit_v,  &
-  &                sysfont
+  &                draw_flag, draw_region_p, draw_region_z, draw_region_t,  &
+  &                IWS, unit_v, sysfont, septlopt, diff_ref, diff_typ
   read(5,nml=input)
 
   if(z_ref==-999.0)then
@@ -113,12 +117,12 @@ program sound_1d
      end do
   end do
 
-!-- ۥɥչѥ顼.
+!-- ホドグラフ高度用カラーの設定.
   call color_setting( 10, draw_region_z, col_min=15, col_max=85 )
   col_num=(/((153+7*(i-1)*10),i=1,11)/)
   col_lev=(/((draw_region_z(1)+((draw_region_z(2)-draw_region_z(1))/10.0)*real(i-1)),i=1,11)/)
 
-!-- ɤ߹ǡեο
+!-- 読み込むデータファイルの数を選定
   nnz=line_number_counter( trim(list_name) )
 
   allocate(fname(2,nnz))
@@ -154,11 +158,11 @@ program sound_1d
   do i=1,nnz
 
   if(trim(fname(1,i))/='unknown')then
-!-- ƥȥեɤ߹
+!-- テキストファイル読み込み部
 
-     nz=line_number_counter( trim(fname(1,i)) )-skip_num  ! ƥȥñ̤ʬð
+     nz=line_number_counter( trim(fname(1,i)) )-skip_num  ! 各タイトルと単位の分差っ引く
 
-!-- 
+!-- 配列割付部
 
      allocate(cval(6,nz))
      allocate(height(nz))
@@ -171,10 +175,12 @@ program sound_1d
      allocate(pt(nz))
      allocate(ept(nz))
      allocate(sept(nz))
-     allocate(draw_tate(nz,4))
-     allocate(draw_yoko(nz,4))
+     allocate(p_height(nz))
+     allocate(temp_v(nz))
+     allocate(draw_tate(nz,5))
+     allocate(draw_yoko(nz,5))
 
-!-- ե뤫ǡɤ߹
+!-- ファイルからデータの読み込み
      call read_file_text( trim(fname(1,i)), 6, nz, cval, skip=skip_num )
      write(*,*) "reading file ", trim(fname(1,i))
 
@@ -188,9 +194,9 @@ program sound_1d
         ww(j)=c2r_convert( cval(6,j) )
      end do
 
-!-- z_ref  p_ref ֤
+!-- z_ref を p_ref で置き換える処理
      if(refer_flag=='p')then
-        ! interpo 뤿󲽽
+        ! interpo させるための漸増配列化処理
         do j=1,nz
            tmp(j)=pres(nz-j+1)
         end do
@@ -199,9 +205,9 @@ program sound_1d
   &                             p_ref, z_ref )
      end if
 
-!-- p_ref  z_ref ֤
+!-- p_ref を z_ref で置き換える処理
      if(refer_flag=='z')then
-        ! interpo 뤿󲽽
+        ! interpo させるための漸増配列化処理
         do j=1,nz
            tmp(j)=pres(nz-j+1)
         end do
@@ -210,27 +216,27 @@ program sound_1d
   &                             z_ref, p_ref )
      end if
 
-!-- z_ref  p_ref ֤
-!  ν¿ʬʤ.
+!-- z_ref を p_ref で置き換える処理
+!  この処理は多分いらない.
 !     if(z_ref==-999.0)then
-        ! interpo 뤿󲽽
+        ! interpo させるための漸増配列化処理
 !        call interpo_search_1d( height, z_ref, iz )
 !        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
 !  &                             z_ref, p_ref )
 !     end if
 
-!-- ή԰ѥ᡼׻
-!-- 1. CAPE ׻
+!-- 対流不安定性パラメータ計算
+!-- 1. CAPE 計算
      cape_c=CAPE( pres, height, qv, temp, z_ref, undeff=undef, copt=cape_opt )!, opt=2 )
 !     write(*,*) "MESSAGE : CAPE option is 2."
 
-!-- 2. CIN ׻
-     cin_c=CIN( pres, height, qv, temp, z_ref, undef )
+!-- 2. CIN 計算
+     cin_c=CIN( pres, height, qv, temp, z_ref, undef, nega_force=.true. )
 
-!-- 3. Ĺ߿̷׻
+!-- 3. 可降水量計算
      precip=precip_water( pres, qv, undef )
 
-!-- 4. LCL ٷ׻
+!-- 4. LCL 高度計算
      height_lcl=z_LCL( z_ref, height, temp, pres, qv )
      call interpo_search_1d( height, height_lcl, iz, int(undef) )
      if(iz/=int(undef))then
@@ -240,7 +246,7 @@ program sound_1d
         pres_lcl=undef
      end if
 
-!-- 5. LFC ٷ׻
+!-- 5. LFC 高度計算
      height_lfc=z_LFC( z_ref, height, temp, pres, qv )
      call interpo_search_1d( height, height_lfc, iz, int(undef) )
      if(iz/=int(undef))then
@@ -250,7 +256,7 @@ program sound_1d
         pres_lfc=undef
      end if
 
-!-- 6. LNB ٷ׻
+!-- 6. LNB 高度計算
      height_lnb=z_LNB( z_ref, height, temp, pres, qv )
      call interpo_search_1d( height, height_lnb, iz, int(undef) )
      if(iz/=int(undef))then
@@ -260,7 +266,7 @@ program sound_1d
         pres_lnb=undef
      end if
 
-!-- 7. ⤷, ʬ¾Υѥ᡼׻ǽ.
+!-- 7. もしかしたら, この部分に他のパラメータ計算処理が今後入る可能性.
 
 !-- 8. data -> array
 
@@ -276,7 +282,7 @@ program sound_1d
      write_data(i,10)=pres_lfc
      write_data(i,11)=pres_lnb
 
-!-- ʬۺʬ
+!-- 温位分布作成部分
      if(draw_flag(1:1)/='x')then
         do j=1,nz
            if(temp(j)/=undef.and.qv(j)/=undef.and.pres(j)/=undef)then
@@ -297,7 +303,7 @@ program sound_1d
         end do
      end if
 
-!-- ۥɥʬۺʬ
+!-- ホドグラフ分布作成部分
      if(draw_flag(5:5)=='o')then
         do j=1,nz
            draw_tate(j,1)=height(j)
@@ -311,16 +317,52 @@ program sound_1d
         end do
      end if
 
-!-- skew-T ץåȺʬ
+!-- 静力学高度差分布作成部分
+     if(draw_flag(6:6)=='o')then
+        select case (diff_typ(1:1))
+        case ('p')
+           call interpo_search_1d( -pres, -diff_ref, i_nz )  ! pres に未定義がある場合を考慮していない
+        case ('z')
+           call interpo_search_1d( height, diff_ref, i_nz )  ! height に未定義がある場合を考慮していない
+        end select
+        i_height=i_nz
+        draw_yoko(i_height:nz,5)=0.0
+        p_height(i_height:nz)=height(i_height:nz)
+        if(temp(i_height)/=undef.and.qv(i_height)/=undef)then
+           temp_v(i_height)=qvT_2_Tv( qv(i_height), temp(i_height) )
+        else
+           temp_v(i_height)=undef
+        end if
+        draw_tate(i_height,5)=height(i_height)
+        do j=i_height-1,1,-1  ! 観測最上部データを真値として下向きに積算する
+           if(temp(j)/=undef.and.height(j)/=undef.and.pres(j)/=undef.and.  &
+              temp(i_height)/=undef.and.height(i_height)/=undef.and.  &
+  &           pres(i_height)/=undef.and.qv(j)/=undef.and.temp_v(i_height)/=undef)then
+              temp_v(j)=qvT_2_Tv( qv(j), temp(j) )
+              p_height(j)=p_height(i_height)-0.5*(Rd/g)*(log(pres(j)/pres(i_height)))  &
+  &                                             *(temp_v(j)+temp_v(i_height))
+              draw_yoko(j,5)=p_height(j)-height(j)
+              i_height=j
+              draw_tate(j,5)=height(j)
+           else
+              p_height(j)=undef
+              temp_v(j)=undef
+              draw_yoko(j,5)=undef
+              draw_tate(j,5)=undef
+           end if
+           write(*,*) "draw check", draw_yoko(j,5), draw_tate(j,5), j
+        end do
+     end if
+
+!-- skew-T プロット作成部分
 
      if(draw_flag(1:1)=='o')then
         call DclSetParm( 'GRAPH:LCLIP', .true. )
         call Dcl_PL( 'l', trim(fname(2,i)),  &
   &                  draw_yoko(:,1:3), draw_tate(:,1:3),  &
   &                  draw_yoko(:,1:3), draw_tate(:,1:3),  &
-  &                  (/achar(241)//'(black), '//achar(241)//'\_{e}(red), '//  &
-  &                    achar(241)//'\_{es}(green)  (K)', 'height (m)'/),  &
-  &                  x_int=(/280.0, 380.0/), y_int=draw_region_z,  &
+  &                  (/'θ(black), θ\_{e}(red), θ\_{es}(green) (K)', 'height (m)                                  '/),  &
+  &                  x_int=draw_region_t, y_int=draw_region_z,  &
   &                  viewx_int=(/0.3, 0.7/), viewy_int=(/0.2, 0.8/),  &
   &                  l_idx=(/14,24,34/) )
         if(draw_flag(3:3)=='o')then
@@ -338,6 +380,9 @@ program sound_1d
            do j=1,jmax
               if(trim(adjustl(title_u(j)))=='hPa'.and.write_data(i,j)/=undef)then
                  skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
+              else if(trim(adjustl(title_c(j)))=='CAPE'.and.  &
+  &                   write_data(i,j)<0.0.and.write_data(i,j)/=undef)then  ! copt=2
+                 skew_c=trim(title_c(j))//' >'//r2c_convert( -write_data(i,j), '(f8.1)' )
               else
                  skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
               end if
@@ -350,9 +395,10 @@ program sound_1d
 
      if(draw_flag(2:2)=='o')then
         call DclSetParm( 'GRAPH:LCLIP', .true. )
-        call SkewT( trim(fname(2,i)), 30.0, (/255.0, 315.0/),  &
+        call SkewT( trim(fname(2,i)), 30.0, draw_region_t,  &
   &                 draw_region_p, temp, pres, qv, height,  &
-  &                 undef=undef, refh=p_ref, heiopt=.false. )
+  &                 undef=undef, refh=p_ref, heiopt=.false.,  &
+  &                 septlopt=septlopt )
         if(draw_flag(3:3)=='o')then
            call DclSetParm( 'GRAPH:LCLIP', .false. )
            CALL SGQVPT( vx_new(1), vx_new(2), vy_new(1), vy_new(2) )
@@ -367,6 +413,9 @@ program sound_1d
            do j=1,jmax
               if(trim(adjustl(title_u(j)))=='hPa'.and.write_data(i,j)/=undef)then
                  skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
+              else if(trim(adjustl(title_c(j)))=='CAPE'.and.  &
+  &                   write_data(i,j)<0.0.and.write_data(i,j)/=undef)then  ! copt=2
+                 skew_c=trim(title_c(j))//' >'//r2c_convert( -write_data(i,j), '(f8.1)' )
               else
                  skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
               end if
@@ -377,7 +426,7 @@ program sound_1d
         end if
      end if
 
-!-- ۥɥʬ
+!-- ホドグラフ描画部分
 
      if(draw_flag(5:5)=='o')then
         call interpo_search_1d( height, draw_region_z(1), idz_min )
@@ -397,10 +446,10 @@ program sound_1d
   &                  draw_tate(idz_min:idz_max,4:4),  &
   &                  draw_yoko(idz_min:idz_max,4:4),  &
   &                  draw_tate(idz_min:idz_max,4:4),  &
-  &                  (/'Zonal Wind', 'Meridional Wind'/),  &
+  &                  (/'Zonal Wind     ', 'Meridional Wind'/),  &
   &                  cl_val=col_lev, cl_idx=col_num,  &
   &                  zline=draw_tate(idz_min:idz_max,1:1) )
-                     ! draw_tate Ͼ Ema ǹ٤ȤƻȤäƤ.
+                     ! draw_tate は上の Ema 作成で高度として使っている.
         CALL SGQVPT( vx_new(1), vx_new(2), vy_new(1), vy_new(2) )
         call tone_bar( 10, draw_region_z,  &
   &                    (/vx_new(2)+0.025, vx_new(2)+0.05/), vy_new,  &
@@ -408,6 +457,20 @@ program sound_1d
   &                    title='height [m]', titles='t', titlep=0.0 )
      end if
 
+!-- データチェック用描画部分
+
+     if(draw_flag(6:6)=='o')then
+        call DclSetParm( 'GRAPH:LCLIP', .true. )
+        call Dcl_PL( 'l', trim(fname(2,i)),  &
+  &                  draw_yoko(1:i_nz,5:5), draw_tate(1:i_nz,5:5),  &
+  &                  draw_yoko(1:i_nz,5:5), draw_tate(1:i_nz,5:5),  &
+  &                  (/'ΔZ\_{hydro-orig} (m)', 'height (m)           '/),  &
+  &                  x_int=draw_region_t, y_int=draw_region_z,  &
+  &                  viewx_int=(/0.3, 0.7/), viewy_int=(/0.2, 0.8/),  &
+  &                  l_idx=(/14/) )
+        call DclDrawLine( (/0.0,0.0/), draw_region_z, 2, 12 )
+     end if
+
      deallocate(cval)
      deallocate(height)
      deallocate(temp)
@@ -419,6 +482,8 @@ program sound_1d
      deallocate(pt)
      deallocate(ept)
      deallocate(sept)
+     deallocate(p_height)
+     deallocate(temp_v)
      deallocate(draw_tate)
      deallocate(draw_yoko)
 
@@ -433,9 +498,9 @@ program sound_1d
      call DclCloseGraphics
   end if
 
-!-- 10. Ƽѥ᡼Υƥȥǡ¸
+!-- 10. 各種パラメータのテキストデータ保存
 
-  if(dmp_flag.eqv..true.)then  ! ήѥ᡼ƥȥǡȤ¸.
+  if(dmp_flag.eqv..true.)then  ! 対流パラメータをテキストデータとして保存する.
 
      open(unit=10,file='convec_parm'//trim(list_name),status='unknown')
      tmp_char="'data name' "//"'reference height' "//"'reference pressure' "  &
