@@ -1,10 +1,10 @@
 program sound_2d
-! ʣΥǥǡƹ٤ˤĤƥڥȥ׻, ȿˤĤƤ
-! ڥȥޤץ.
-! ꥹȥǡΥեޥåȤ
+! 複数のゾンデデータから各高度についてスペクトルを計算し, 各波数についての
+! スペクトル時系列図を作成するプログラム.
+! リストデータのフォーマットは
 ! YYYYMMDDHH file_name
-! FFT ׻Ѥ뤿, ɬǡƤ뤳.
-! ̤ 1/day ñ̤ɽ. Ǥδ¬ֳ֤ 6 ٤Ǥ뤿.
+! FFT 計算を用いるため, 必ずデータが埋められていること.
+! 結果は 1/day 単位で表示する. ゾンデの観測間隔が 6 時間程度であるため.
 
   use dcl
   use Dcl_Automatic
@@ -18,25 +18,25 @@ program sound_2d
   implicit none
 
 !-- integer
-  integer :: nt       ! γʻҿ
-  integer :: nz       ! z γʻҿ
-  integer :: nf       ! conv_dat ѥǡ
-  integer :: IWS      ! ǥХ
-  integer :: dt       ! ǡλֳִ [s]
-  integer :: period   ! ǡΥȡ [s]
-  integer :: i_counter    ! 󥿡
-  integer :: i_counter_c  ! 󥿡
-  integer :: snum, cnum  ! 顼ο
-  integer :: cont_flag, shade_flag  ! 顼, ѥե饰ѿ
+  integer :: nt       ! 時間方向の格子数
+  integer :: nz       ! z 方向の格子数
+  integer :: nf       ! conv_dat 用データ数
+  integer :: IWS      ! 描画デバイス
+  integer :: dt       ! データの時間間隔 [s]
+  integer :: period   ! データのトータル時間 [s]
+  integer :: i_counter    ! 一時カウンター
+  integer :: i_counter_c  ! 一時カウンター
+  integer :: snum, cnum  ! カラーおよび等値線の数
+  integer :: cont_flag, shade_flag  ! カラー, 等値線用フラグ変数
   integer :: prim(5)
-  integer, allocatable, dimension(:) :: year_v    ! ǯ
-  integer, allocatable, dimension(:) :: month_v   ! 
-  integer, allocatable, dimension(:) :: day_v     ! 
-  integer, allocatable, dimension(:) :: hour_v    ! 
-  integer, allocatable, dimension(:) :: inter_z ! ѹ
-  integer, allocatable, dimension(:) :: i_flag  ! 
-  integer, allocatable, dimension(:) :: o_flag  ! 
-  integer, allocatable, dimension(:) :: c_flag  ! 
+  integer, allocatable, dimension(:) :: year_v    ! 年
+  integer, allocatable, dimension(:) :: month_v   ! 月
+  integer, allocatable, dimension(:) :: day_v     ! 日
+  integer, allocatable, dimension(:) :: hour_v    ! 時間
+  integer, allocatable, dimension(:) :: inter_z ! 内挿用高度配列
+  integer, allocatable, dimension(:) :: i_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: o_flag  ! 一時配列
+  integer, allocatable, dimension(:) :: c_flag  ! 一時配列
 !-- tmp
   integer :: nttmp, i, j, k, i_undef
 !-- parameter
@@ -44,47 +44,47 @@ program sound_2d
   integer, parameter :: skip_num=2
 
 !-- real
-  real :: z_bot       ! βü
-  real :: z_top       ! ξü
-  real :: dz          ! ľֳ [m]
-  real :: dvy         ! vy δֳ
-  real :: smax, smin, cmax, cmin  ! 顼, ξ
-  real, allocatable, dimension(:) :: freq  ! ư
-  real, allocatable, dimension(:) :: z     ! ٺɸ
-  real, allocatable, dimension(:) :: vx     ! viewport 
-  real, allocatable, dimension(:,:) :: vy     ! viewport 
-  real, allocatable, dimension(:,:) :: val_f        ! ׻
-  real, allocatable, dimension(:,:) :: val_inter    ! ׻ѿ
-  real, allocatable, dimension(:,:) :: tline        ! ׻ѿ
-  real, allocatable, dimension(:,:) :: yline        ! ׻ѿ
-  real, allocatable, dimension(:,:,:) :: val_tmp    ! ׻ѿ
-  real, allocatable, dimension(:,:,:) :: val_draw   ! ѿ
+  real :: z_bot       ! 描画の下端
+  real :: z_top       ! 描画の上端
+  real :: dz          ! 鉛直方向の描画間隔 [m]
+  real :: dvy         ! vy の間隔
+  real :: smax, smin, cmax, cmin  ! カラー, 等値線の上限
+  real, allocatable, dimension(:) :: freq  ! 振動数
+  real, allocatable, dimension(:) :: z     ! 高度座標
+  real, allocatable, dimension(:) :: vx     ! viewport 配列
+  real, allocatable, dimension(:,:) :: vy     ! viewport 配列
+  real, allocatable, dimension(:,:) :: val_f        ! 計算用配列
+  real, allocatable, dimension(:,:) :: val_inter    ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: tline        ! 計算用変数配列
+  real, allocatable, dimension(:,:) :: yline        ! 計算用変数配列
+  real, allocatable, dimension(:,:,:) :: val_tmp    ! 計算用変数配列
+  real, allocatable, dimension(:,:,:) :: val_draw   ! 描画用変数配列
   real :: undef
   real :: conv_undef
 !-- tmp
   real, dimension(2) :: pt_tmp, ept_tmp, sept_tmp, rh_tmp, s_int, c_int
 
 !-- complex part
-  complex, allocatable, dimension(:) :: val_fft   ! ׻ѿ
-  complex, allocatable, dimension(:,:) :: omegar    ! ׻ѿ
-  complex, allocatable, dimension(:,:) :: omeganr   ! ׻ѿ
+  complex, allocatable, dimension(:) :: val_fft   ! 計算用変数配列
+  complex, allocatable, dimension(:,:) :: omegar    ! 計算用変数配列
+  complex, allocatable, dimension(:,:) :: omeganr   ! 計算用変数配列
 
 !-- character
-  character(1000) :: flist         ! եꥹ̾
-  character(1000) :: conv_dat      ! sound_1d ǽϤήѥ᡼ǡ
-  character(1000) :: title_txt     ! ȥ̾
-  character(10) :: cont_val      ! ѿ̾
-  character(10) :: shade_val     ! 顼ѿ̾
-  character(10) :: conv_list     ! ǡե饰
-  character(1000), allocatable, dimension(:,:) :: fname  ! ե̾
-  character(1000), allocatable, dimension(:,:) :: val_w  ! ƥȥǡ
+  character(1000) :: flist         ! ファイルリスト名
+  character(1000) :: conv_dat      ! sound_1d で出力した対流パラメータ時系列データ
+  character(1000) :: title_txt     ! タイトル名
+  character(10) :: cont_val      ! 等値線描画用変数名
+  character(10) :: shade_val     ! カラー描画用変数名
+  character(10) :: conv_list     ! カラムデータフラグ
+  character(1000), allocatable, dimension(:,:) :: fname  ! ファイル名
+  character(1000), allocatable, dimension(:,:) :: val_w  ! テキストデータ
   character(70) :: sysfont
 !-- tmp
   character(1000) :: tmp_c
 
 !-- logical
-  logical :: mean_flag       ! ʿѾ (FFT  0 ʬ) ե饰
-  logical, allocatable, dimension(:) :: fflag  ! ƹ٤ undef  1 ĤǤäƤ뤫.
+  logical :: mean_flag       ! 平均場 (FFT 第 0 成分) 描画フラグ
+  logical, allocatable, dimension(:) :: fflag  ! 各高度に undef が 1 つでも入っているか.
 
 !-- namelist reading
   namelist /input /flist, conv_dat, conv_list, conv_undef, dz, z_bot,  &
@@ -96,7 +96,7 @@ program sound_2d
   nz=int((z_top-z_bot)/dz)+1
   nt=line_number_counter( trim(flist) )
   if(mod(nt,2)/=0)then
-     nt=nt-1  ! ξ, ֤.
+     nt=nt-1  ! 奇数の場合, 偶数に置き換え.
   end if
   period=dt*(nt-1)
   s_int=(/smin, smax/)
@@ -152,16 +152,16 @@ program sound_2d
      freq(i)=86400.0*real(i-1)/real(period)
   end do
 
-!-- fft 
-!-- ǡǰʬ
+!-- fft の前処理
+!-- データ数の素因数分解
   call prim_calc( nt, prim(1:4), prim(5) )
   write(*,*) "prime factor", prim(:)
 
-!-- žη׻
+!-- 回転行列の計算
   call rotate_array_f()
   call rotate_calc( nt/2, 'r', (/prim(1)-1,prim(2),prim(3),prim(4),prim(5)/),  &
   &                 omegar(1:prim(5),1:prim(5)),  &
-  &                 omeganr(1:nt/2,1:nt/2) )  ! ¥ǡ FFT ʤΤ, ǡ 1/2 Ȥʤ. ȼ, prim_fact(1)  -1 Ȥʤ.
+  &                 omeganr(1:nt/2,1:nt/2) )  ! 実データの FFT なので, データ数は 1/2 となる. それに伴い, prim_fact(1) も -1 となる.
 
 !-- time loop
 !-- 1. reading values from text file
@@ -259,7 +259,7 @@ program sound_2d
 
   end do
 
-!-- ֥ǡ򥹥ڥȥǡѴ.
+!-- 時間データをスペクトルデータに変換.
 
   do k=1,nz
      if(fflag(k).eqv..false.)then
@@ -281,7 +281,7 @@ program sound_2d
   end do
 
 !-- draw value separate
-!--  val_inter ȤƤ.(ޤ̤)
+!-- 全て val_inter に落としておく.(上まだ未完全)
 
   select case (cont_val)
   case ('temp')
@@ -322,7 +322,7 @@ program sound_2d
   end select
 
 !-- DCL part
-!-- ޤ, -
+!-- まず, 高度-時系列断面
   call color_setting( snum, s_int, col_min=15, col_max=85,  &
   &                   min_tab=10999, max_tab=99999 )
 
