@@ -1,6 +1,6 @@
 program read_mgdsst_nc
-  ! mgdsst Υꥸʥǡ GrADS or NetCDF Ѵץ
-  ! sst_list ˺ǡե񤭹, ưǺ.
+  ! mgdsst のオリジナルデータを GrADS or NetCDF 形式に変換するプログラム
+  ! sst_list に作るデータファイルを書き込めば, 自動で作成する.
 
   use file_operate
   use gtool_history
@@ -42,11 +42,11 @@ program read_mgdsst_nc
   end if
 
   do i=1,dat_line
-     call read_mgdsst( trim(dat_list(i)), sst )  ! ɤ߹
+     call read_mgdsst( trim(dat_list(i)), sst )  ! ここで読み込む
 
      select case (dtype)
      case (1)
-        call HistoryCreate( &                             ! ҥȥ꡼
+        call HistoryCreate( &                             ! ヒストリー作成
           & file=trim(dat_list(i))//'.nc',  &
           & title=trim(dat_list(i))//'sst data', &
           & source='Sample program of gtool_history/gtool5',   &
@@ -56,10 +56,10 @@ program read_mgdsst_nc
           & units=(/'deg','deg'/),                                 &
           & origin=0.0, interval=0.0 )
 
-        call HistoryPut( 'lon', lon )                            ! ѿ
-        call HistoryPut( 'lat', lat )                            ! ѿ
+        call HistoryPut( 'lon', lon )                            ! 次元変数出力
+        call HistoryPut( 'lat', lat )                            ! 次元変数出力
 
-        call HistoryAddVariable( &                           ! ѿ
+        call HistoryAddVariable( &                           ! 変数定義
           & varname='sst', dims=(/'lon','lat'/), &
           & longname='sea surface temperature', units='K', xtype='float')
 
