@@ -17,7 +17,7 @@ module Algebra   ! 代数演算を主に行うモジュール
 
 interface rectangle_int
 
-  module procedure rectangle_intf, rectangle_intd
+  module procedure rectangle_intf, rectangle_intd, rectangle_intcp, rectangle_intcpd
 
 end interface rectangle_int
 
@@ -83,7 +83,7 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 次元台形積分
 !-- bot < top でなければエラー
   if(bot>top)then
      write(*,*) "#### ERROR (algebra:rectangle_int) ####"
-     write(*,*) "integrated interval must be bot < top. STOP"
+     write(*,*) "integrated interval must be bot < top. STOP", bot, top
      stop
   end if
 
@@ -95,7 +95,8 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 次元台形積分
         if(x(i)/=undeff)then
            if(x(i)>bot)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
+              write(*,*) "there is NOT the bot in the x(i).", bot, x(i), i
+              ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
            end if
            exit
         end if
@@ -105,7 +106,8 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 次元台形積分
         if(x(i)/=undeff)then
            if(x(i)<top)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
+              write(*,*) "there is NOT the top in the x(i).", top, x(i), i
+              ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
            end if
            exit
         end if
@@ -133,11 +135,13 @@ subroutine rectangle_intf( x, y, bot, top, res, undeff )  ! 1 次元台形積分
 
      if(x(1)>bot)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
+        write(*,*) "there is NOT the bot in the x(1).", bot, x(1)
+        ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
      end if
      if(x(nx)<top)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
+        write(*,*) "there is NOT the top in the x(nx).", top, x(nx)
+        ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
      end if
 
      do i=1,nx
@@ -253,7 +257,7 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
 !-- bot < top でなければエラー
   if(bot>top)then
      write(*,*) "#### ERROR (algebra:rectangle_int) ####"
-     write(*,*) "integrated interval must be bot < top. STOP"
+     write(*,*) "integrated interval must be bot < top. STOP", bot, top
      stop
   end if
 
@@ -265,7 +269,8 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
         if(x(i)/=undeff)then
            if(x(i)>bot)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
+              write(*,*) "there is NOT the bot in the x(i).", bot, x(i), i
+              ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
            end if
            exit
         end if
@@ -275,7 +280,8 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
         if(x(i)/=undeff)then
            if(x(i)<top)then
               write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-              write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
+              write(*,*) "there is NOT the top in the x(i).", top, x(i), i
+              ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
            end if
            exit
         end if
@@ -303,11 +309,13 @@ subroutine rectangle_intd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
 
      if(x(1)>bot)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the bot in the x(i)."  ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
+        write(*,*) "there is NOT the bot in the x(1).", bot, x(1)
+        ! このときは, i_bot=1としておいても, x(1)=bot なので, 余分計算はゼロとなり影響はない.
      end if
      if(x(nx)<top)then
         write(*,*) "#### WARNING (algebra:rectangle_int) ####"
-        write(*,*) "there is NOT the top in the x(i)."  ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
+        write(*,*) "there is NOT the top in the x(nx).", top, x(nx)
+        ! このとき, i_top=nx としても, x(nx)=top なので, 余分計算はゼロとなる.
      end if
 
      do i=1,nx
@@ -399,6 +407,86 @@ end subroutine rectangle_intd
 !------------------------------------------
 !------------------------------------------
 
+subroutine rectangle_intcp( x, y, bot, top, res, undeff )  ! 1 次元台形積分
+  ! 不等間隔でも計算可能であるが, 精度は保証しない.
+  implicit none
+  real, intent(in) :: bot  ! 積分区間左端
+  real, intent(in) :: top  ! 積分区間右端
+  real, intent(in) :: x(:)  ! 積分変数
+  complex, intent(in) :: y(size(x))  ! 非積分関数
+  complex, intent(inout) :: res  ! 台形積分の積分値
+  real, intent(in), optional :: undeff
+  integer :: i, nx, i_bot, i_top
+  real :: tmpr(size(x)), tmpi(size(x))
+  real :: tmprres, tmpires
+  complex, parameter :: img_unit=(0.0,1.0)
+
+  nx=size(x)
+
+  do i=1,nx
+     tmpr(i)=real(y(i))
+     tmpi(i)=aimag(y(i))
+  end do
+
+  if(present(undeff))then
+     call rectangle_intf( x, tmpr, bot, top, tmprres, undeff )
+     call rectangle_intf( x, tmpi, bot, top, tmpires, undeff )
+     if(tmprres/=undeff.and.tmpires/=undeff)then
+        res=tmprres+img_unit*tmpires
+     else
+        res=undeff+img_unit*undeff
+     end if
+  else
+     call rectangle_intf( x, tmpr, bot, top, tmprres )
+     call rectangle_intf( x, tmpi, bot, top, tmpires )
+     res=tmprres+img_unit*tmpires
+  end if
+
+end subroutine rectangle_intcp
+
+!------------------------------------------
+!------------------------------------------
+
+subroutine rectangle_intcpd( x, y, bot, top, res, undeff )  ! 1 次元台形積分
+  ! 不等間隔でも計算可能であるが, 精度は保証しない.
+  implicit none
+  double precision, intent(in) :: bot  ! 積分区間左端
+  double precision, intent(in) :: top  ! 積分区間右端
+  double precision, intent(in) :: x(:)  ! 積分変数
+  complex(kind(0d0)), intent(in) :: y(size(x))  ! 非積分関数
+  complex(kind(0d0)), intent(inout) :: res  ! 台形積分の積分値
+  double precision, intent(in), optional :: undeff
+  integer :: i, nx, i_bot, i_top
+  double precision :: tmpr(size(x)), tmpi(size(x))
+  double precision :: tmprres, tmpires
+  complex(kind(0d0)), parameter :: img_unit=(0.0d0,1.0d0)
+
+  nx=size(x)
+
+  do i=1,nx
+     tmpr(i)=dble(y(i))
+     tmpi(i)=dimag(y(i))
+  end do
+
+  if(present(undeff))then
+     call rectangle_intd( x, tmpr, bot, top, tmprres, undeff )
+     call rectangle_intd( x, tmpi, bot, top, tmpires, undeff )
+     if(tmprres/=undeff.and.tmpires/=undeff)then
+        res=tmprres+img_unit*tmpires
+     else
+        res=undeff+img_unit*undeff
+     end if
+  else
+     call rectangle_intd( x(1:nx), tmpr(1:nx), bot, top, tmprres )
+     call rectangle_intd( x(1:nx), tmpi(1:nx), bot, top, tmpires )
+     res=tmprres+img_unit*tmpires
+  end if
+
+end subroutine rectangle_intcpd
+
+!------------------------------------------
+!------------------------------------------
+
 subroutine rectangle_int_2d( x, y, z, botx, topx, boty, topy, res, undeff )
   ! 2 次元台形積分
   ! 不等間隔でも計算可能であるが, 精度は保証しない.
