@@ -3,7 +3,7 @@
 !---------------------------------------------------------------
 
 module cloud
-! CReSS αʪ
+! CReSS の雲物理過程
   use Thermo_Function
   use Thermo_Const
   use special_function
@@ -11,13 +11,13 @@ module cloud
 contains
 
 real function Src_theta_warm( temp, pres, qv, qr )
-! warm rain Ǥ theta Υ
+! warm rain 過程での theta のソース項
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  ! ȡ뵤 [Pa]
-  real, intent(in) :: qv  !  [kg/kg]
-  real, intent(in) :: qr  ! 庮 [kg/kg]
+  real, intent(in) :: temp  ! 気温 [K]
+  real, intent(in) :: pres  ! トータル気圧 [Pa]
+  real, intent(in) :: qv  ! 水蒸気混合比 [kg/kg]
+  real, intent(in) :: qr  ! 雨水混合比 [kg/kg]
   real :: vapor_qv, rhob
 
   vapor_qv=qvss( temp, pres )
@@ -34,22 +34,22 @@ end function Src_theta_warm
 !---------------------------------
 
 !!!real function Src_theta_cold( rhob, rhop, rho0, ptb, ptp, pb, pp, qv, qc, qr, qi, qs, qg )
-!!!! warm rain Ǥ theta Υ
+!!!! warm rain 過程での theta のソース項
 !!!  use Thermo_Const
 !!!  implicit none
-!!!  real, intent(in) :: rhob  ! ܾ̩ [kg/m3]
-!!!  real, intent(in) :: rhop  ! ̩٤ư [kg/m3]
-!!!  real, intent(in) :: rho0  ! ɽ̤δܾ̩ [kg/m3]
-!!!  real, intent(in) :: ptb  ! ̤δܾ [K]
-!!!  real, intent(in) :: ptp  ! ̤ư [K]
-!!!  real, intent(in) :: pb  ! ̤δܾ [K]
-!!!  real, intent(in) :: pp  ! ̤ư [K]
-!!!  real, intent(in) :: qv  !  [kg/kg]
-!!!  real, intent(in) :: qc  ! 庮 [kg/kg]
-!!!  real, intent(in) :: qr  ! 庮 [kg/kg]
-!!!  real, intent(in) :: qi  ! ɹ [kg/kg]
-!!!  real, intent(in) :: qs  ! 㺮 [kg/kg]
-!!!  real, intent(in) :: qg  ! Ǻ [kg/kg]
+!!!  real, intent(in) :: rhob  ! 基本場の密度 [kg/m3]
+!!!  real, intent(in) :: rhop  ! 密度の変動 [kg/m3]
+!!!  real, intent(in) :: rho0  ! 地表面の基本場密度 [kg/m3]
+!!!  real, intent(in) :: ptb  ! 温位の基本場 [K]
+!!!  real, intent(in) :: ptp  ! 温位の変動 [K]
+!!!  real, intent(in) :: pb  ! 温位の基本場 [K]
+!!!  real, intent(in) :: pp  ! 温位の変動 [K]
+!!!  real, intent(in) :: qv  ! 水蒸気混合比 [kg/kg]
+!!!  real, intent(in) :: qc  ! 雲水混合比 [kg/kg]
+!!!  real, intent(in) :: qr  ! 雨水混合比 [kg/kg]
+!!!  real, intent(in) :: qi  ! 雲氷混合比 [kg/kg]
+!!!  real, intent(in) :: qs  ! 雪混合比 [kg/kg]
+!!!  real, intent(in) :: qg  ! 霰混合比 [kg/kg]
 !!!  real :: vapor_qv
 !!!
 !!!  vapor_qv=qvs( temp )
@@ -70,10 +70,10 @@ end function Src_theta_warm
 !---------------------------------
 
 real function Lv( temp )
-!  -> ǤǮǮ
+! 水 -> 水蒸気での潜熱加熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
+  real, intent(in) :: temp  ! 温度 [K]
 
   Lv=2.50078e6*(ti0/temp)**(0.167+3.67e-4*temp)
 
@@ -82,10 +82,10 @@ real function Lv( temp )
 end function Lv
 
 real function Ls( temp )
-! ɹ -> ǤǮǮ
+! 氷 -> 水蒸気での潜熱加熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
+  real, intent(in) :: temp ! 温度 [K]
 
   Ls=2.834e6+100.0*(temp-ti0)
 
@@ -94,10 +94,10 @@ real function Ls( temp )
 end function Ls
 
 real function Lf( temp )
-!  -> ɹǤͻǮ
+! 水 -> 氷での融解熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
+  real, intent(in) :: temp ! 温度 [K]
 
   Lf=3.34e5+2500.0*(temp-ti0)
 
@@ -106,11 +106,11 @@ real function Lf( temp )
 end function Lf
 
 real function nu_air( pres, temp )
-! ưǴ
+! 空気の動粘性係数
   use Thermo_Const
   implicit none
-  real, intent(in) :: pres !  [Pa]
-  real, intent(in) :: temp !  [K]
+  real, intent(in) :: pres ! 気圧 [Pa]
+  real, intent(in) :: temp ! 温度 [K]
 
   nu_air=1.328e-5*(p00/pres)*(temp/ti0)**1.754
 
@@ -119,7 +119,7 @@ real function nu_air( pres, temp )
 end function nu_air
 
 real function mu_air( pres, temp )
-! Ǵ
+! 空気の粘性係数
   implicit none
   real, intent(in) :: pres
   real, intent(in) :: temp
@@ -166,10 +166,10 @@ end function
 subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
   use Thermo_Const
   implicit none
-  real, intent(in) :: pres !  [Pa]
-  real, intent(inout) :: pt   !  [K]
-  real, intent(inout) :: qv   !  [kg kg-1]
-  real, intent(inout) :: qc   ! 庮 [kg kg-1]
+  real, intent(in) :: pres ! 圧力 [Pa]
+  real, intent(inout) :: pt   ! 温位 [K]
+  real, intent(inout) :: qv   ! 水蒸気混合比 [kg kg-1]
+  real, intent(inout) :: qc   ! 雲水混合比 [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
   real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, coe, pt1, qv1, qc1, err_max
   real :: tmp_err
@@ -265,10 +265,10 @@ end function CLcr
 
 real function EVrv( temp, qv, qr, p )
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: qv    !  [kg/kg]
-  real, intent(in) :: qr    ! 庮 [kg/kg]
-  real, intent(in) :: p     !  [Pa]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: qv    ! 水蒸気混合比 [kg/kg]
+  real, intent(in) :: qr    ! 雨水混合比 [kg/kg]
+  real, intent(in) :: p     ! 圧力 [Pa]
   real :: C, qvs, rhob
 
   rhob=TP_2_rho( temp, p )
@@ -300,10 +300,10 @@ end function term_v_warm
 subroutine Moist_Sature_Adjust_cold( pres, pt, qv, qc, err )
   use Thermo_Const
   implicit none
-  real, intent(in) :: pres !  [Pa]
-  real, intent(inout) :: pt   !  [K]
-  real, intent(inout) :: qv   !  [kg kg-1]
-  real, intent(inout) :: qc   ! 庮 [kg kg-1]
+  real, intent(in) :: pres ! 圧力 [Pa]
+  real, intent(inout) :: pt   ! 温位 [K]
+  real, intent(inout) :: qv   ! 水蒸気混合比 [kg kg-1]
+  real, intent(inout) :: qc   ! 雲水混合比 [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
   real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, coe, pt1, qv1, qc1, err_max
   real :: tmp_err
@@ -360,15 +360,15 @@ end subroutine Moist_Sature_Adjust_cold
 
 
 !!!real function FRrg( temp, rhob, lambdar )
-!!!! γ
+!!!! 雨粒の凍結
 !!!  use Thermo_Const
 !!!  use Cloud_Const
 !!!  use Math_Const
 !!!  implicit none
-!!!  real, intent(in) :: temp  !  [K]
-!!!  real, intent(in) :: rhob  ! ܾ̩ [kg/m3]
-!!!  real, intent(in) :: lambdar  ! γʬۤη
-!!!  real :: tsp  ! Ѳ [K]
+!!!  real, intent(in) :: temp  ! 温度 [K]
+!!!  real, intent(in) :: rhob  ! 基本場の密度 [kg/m3]
+!!!  real, intent(in) :: lambdar  ! 粒径分布の傾き
+!!!  real :: tsp  ! 過冷却温度 [K]
 !!!
 !!!  tsp=ti0-temp
 !!!
@@ -381,18 +381,18 @@ end subroutine Moist_Sature_Adjust_cold
 !!!!-----------------------------------------
 !!!
 !!!real function MLxr( temp, rhob, pres, qv, cat )
-!!!! , Ǥͻ
+!!!! 雪, 霰の融解
 !!!  use Math_Const
 !!!  use Thermo_Const
 !!!  use Cloud_Const
 !!!  implicit none
-!!!  real, intent(in) :: temp  !  [K]
-!!!  real, intent(in) :: rhob  ! ܾ̩ [kg/m3]
-!!!  real, intent(in) :: pres  !  [Pa]
-!!!  real, intent(in) :: qv  !  [kg/kg]
-!!!  character(1), intent(in) :: cat  ! ѴΥƥ
-!!!                ! 's' -> , 'g' -> 
-!!!  real :: tdg  ! 륷
+!!!  real, intent(in) :: temp  ! 温度 [K]
+!!!  real, intent(in) :: rhob  ! 基本場の密度 [kg/m3]
+!!!  real, intent(in) :: pres  ! 圧力 [Pa]
+!!!  real, intent(in) :: qv  ! 水蒸気混合比 [kg/kg]
+!!!  character(1), intent(in) :: cat  ! 変換のカテゴリ
+!!!                ! 's' -> 雪, 'g' -> 霰
+!!!  real :: tdg  ! セルシウス温度
 !!!
 !!!  tdg=temp-t0
 !!!
@@ -411,10 +411,10 @@ end subroutine Moist_Sature_Adjust_cold
 !!!!-----------------------------------------
 !!!
 !!!real function MLic( dt, qi )
-!!!! ɹͻ
+!!!! 雲氷の融解
 !!!  implicit none
 !!!  real, intent(in) :: dt  ! dtbig [s]
-!!!  real, intent(in) :: qi  ! ɹ [kg/kg]
+!!!  real, intent(in) :: qi  ! 雲氷混合比 [kg/kg]
 !!!
 !!!  MLic=0.5*qi/dt
 !!!
@@ -434,13 +434,13 @@ end subroutine Moist_Sature_Adjust_cold
 
 
 real function NUAvi()
-  ! ڳ˷Ǥɹ׻.
+  ! 昇華核形成での氷晶の生成を計算する.
   use Cloud_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: qv    !  [kg/kg]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: qv    ! 水蒸気混合比 [kg/kg]
   real :: tmpa, tmpb, tmpc
 
 
@@ -452,12 +452,12 @@ end function NUAvi
 
 real function MLic( temp, qi, dt )
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: qi    ! ɹ [kg/kg]
-  real, intent(in) :: dt    ! ֳִ [s]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: qi    ! 氷晶混合比 [kg/kg]
+  real, intent(in) :: dt    ! 時間間隔 [s]
 
   if(temp>ti0)then
-     MLic=0.5*qi/dt  ! Leap Frog ΤȤ.
+     MLic=0.5*qi/dt  ! Leap Frog スキームのとき.
   else
      MLic=0.0
   end if
@@ -472,13 +472,13 @@ real function MLxr( q_type, temp, rhob, pres, qv )
   use Cloud_Const
   implicit none
   character(1), intent(in) :: q_type  ! s, g
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: rhob  ! ʿѾ̩ [kg/m^3]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: qv    !  [kg/kg]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: rhob  ! 平均場の密度 [kg/m^3]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: qv    ! 水蒸気混合比 [kg/kg]
   real :: tc
   real, parameter :: Cww=4.17e3
-! ͻϰѲФƤۤȤѲʤȲꤹ. (qvss Ȥ)
+! 水の融点は圧力変化に対してほとんど変化しないと仮定する. (qvss を求めるとき)
 
   if(temp>ti0)then
      tc=temp-ti0
@@ -498,8 +498,8 @@ real function FRrg( temp, rhob )
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: rhob  ! ʿѾ̩ [kg/m^3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: rhob  ! 平均場の密度 [kg/m^3]
   real :: ts
 
   ts=ti0-temp
@@ -532,8 +532,8 @@ real function FRrgN( temp, rhob )
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: rhob  ! ʿѾ̩ [kg/m^3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: rhob  ! 平均場の密度 [kg/m^3]
   real :: ts
 
   ts=ti0-temp
@@ -543,15 +543,15 @@ real function FRrgN( temp, rhob )
 
 end function FRrg
 
-real function CNsg( Ns, lams, qc, rhob )  ! , qc Τ.
+real function CNsg( Ns, lams, qc, rhob )  ! ここ, qc が正しいのかは不明.
   use Math_Const
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Ns    ! οǻ [1/m^3]
-  real, intent(in) :: lams  ! οǻٷ
-  real, intent(in) :: qc    ! κ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
+  real, intent(in) :: Ns    ! 雪の数濃度 [1/m^3]
+  real, intent(in) :: lams  ! 雪の数濃度傾き
+  real, intent(in) :: qc    ! 雲水の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
   real :: tmpa, tmpb, tmpc, Ecs
 
   Ecs=(Stk()/(Stk()+0.5))**2
@@ -565,14 +565,14 @@ real function CNsg( Ns, lams, qc, rhob )  ! , qc Τ.
 
 end function CNsg
 
-real function CNsgN( Ns, qc, rhob )  ! , qc Τ.
+real function CNsgN( Ns, qc, rhob )  ! ここ, qc が正しいのかは不明.
   use Math_Const
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Ns    ! οǻ [1/m^3]
-  real, intent(in) :: qc    ! κ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
+  real, intent(in) :: Ns    ! 雪の数濃度 [1/m^3]
+  real, intent(in) :: qc    ! 雲水の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
   real :: tmpa, tmpb, tmpc, Ecs
 
   Ecs=(Stk()/(Stk()+0.5))**2
@@ -591,26 +591,26 @@ real function CNis( Ns, lams, qc, rhob )  ! under construction
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Ns    ! οǻ [1/m^3]
-  real, intent(in) :: lams  ! οǻٷ
-  real, intent(in) :: qc    ! κ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
+  real, intent(in) :: Ns    ! 雪の数濃度 [1/m^3]
+  real, intent(in) :: lams  ! 雪の数濃度傾き
+  real, intent(in) :: qc    ! 雲水の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
 
   return
 
 end function CNis
 
-real function CNcr( Nc, qc, rhob, sigma, qcm )  ! 꼰ʸǧ
-! Ǥ, Lin 򵭽ҤƤ.
+real function CNcr( Nc, qc, rhob, sigma, qcm )  ! 定式が正しいか原論文確認
+! ここでは, Lin スキームを記述している.
   use Math_Const
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Nc    ! οǻ [1/m^3]
-  real, intent(in) :: qc    ! κ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
-  real, intent(in), optional :: sigma  ! ǻ٤ʬ, default=sigma**2=0.15
-  real, intent(in), optional :: qcm  ! 庮 [kg/kg], default=2.0e-3
+  real, intent(in) :: Nc    ! 雲水の数濃度 [1/m^3]
+  real, intent(in) :: qc    ! 雲水の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
+  real, intent(in), optional :: sigma  ! 雲水数濃度の分散, default=sigma**2=0.15
+  real, intent(in), optional :: qcm  ! 雲水混合比の閾値 [kg/kg], default=2.0e-3
   real :: tmp_qcr, tmp_sigma, coe
 
   if(present(sigma))then
@@ -641,13 +641,13 @@ real function AGiN( Ni, qi, rhob )
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Ni    ! ɹοǻ [1/m^3]
-  real, intent(in) :: qi    ! ɹκ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
+  real, intent(in) :: Ni    ! 雲氷の数濃度 [1/m^3]
+  real, intent(in) :: qi    ! 雲氷の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
   real :: c1
 
   c1=(qi*aui*Eii*spii/rhoi)*((rho0/rhob)**(1.0/3.0))
-  AGiN=-0.5*c1*Ni  ! c1 褫 rhob  AGiN ˤ 1/rhob 껦.
+  AGiN=-0.5*c1*Ni  ! c1 に本来かかる rhob と AGiN にかかる 1/rhob で相殺.
 
   return
 
@@ -658,9 +658,9 @@ real function AGsN( Ns, qs, rhob )
   use Thermo_Const
   use Cloud_Const
   implicit none
-  real, intent(in) :: Ns    ! οǻ [1/m^3]
-  real, intent(in) :: qs    ! κ [kg/kg]
-  real, intent(in) :: rhob  ! 絤̩ [kg/m^3]
+  real, intent(in) :: Ns    ! 雪の数濃度 [1/m^3]
+  real, intent(in) :: qs    ! 雪の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 大気の密度 [kg/m^3]
   real, parameter :: Ibus=1610.0
   real :: c1, c2, c3
 
@@ -677,10 +677,10 @@ real function VDvr( temp, pres, qv, rhob )
   use Cloud_Const
   use Math_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: qv    !  [kg/kg]
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: qv    ! 水蒸気混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
   real :: Sw
 
   Sw=qv/qvss( temp, pres )
@@ -699,9 +699,9 @@ real function Gw( temp, pres, rhob )
   use Math_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
   real :: tmpa, tmpb, tmpc, tmpd
 
   tmpa=Lv(temp)
@@ -719,11 +719,11 @@ real function VENTr( temp, pres, lamr, rhob, rho0 )
   use Math_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: lamr  ! η
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
-  real, intent(in) :: rho0  ! ɽ̤Ǥδ̩ [kg/m3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: lamr  ! 雨の傾き
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
+  real, intent(in) :: rho0  ! 地表面での基準密度 [kg/m3]
   real :: tmp, tmpa, tmpb, tmpc
 
   tmp=0.5*(5.0+bur)
@@ -739,17 +739,17 @@ end function VENTr
 
 
 real function UbxN( types, qx, rhob, rho0, Nx )
-! ǻ٤νŤߤ򤫤ƥ꡼ x νü®٤׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 数濃度の重みをかけたカテゴリー x の終端落下速度を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in) :: rhob   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in) :: rhob   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa, lamxx
 
   if(present(Nx))then
@@ -758,7 +758,7 @@ real function UbxN( types, qx, rhob, rho0, Nx )
      lamxx=lamx( types(1:1), qx, rhob )
   end if
 
-  select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+  select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
   case ('r')
      tmpa=aur*gamma_func(1.0+bur)
      tmpb=lamxx**(bur)
@@ -781,17 +781,17 @@ end function UbxN
 
 
 real function UhxN( types, qx, rhob, rho0, Nx )
-! ̤νŤߤ򤫤ƥ꡼ x νü®٤׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 重量の重みをかけたカテゴリー x の終端落下速度を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in) :: rhob   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in) :: rhob   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa, lamxx
 
   if(present(Nx))then
@@ -800,7 +800,7 @@ real function UhxN( types, qx, rhob, rho0, Nx )
      lamxx=lamx( types(1:1), qx, rhob )
   end if
 
-  select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+  select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
   case ('r')
      tmpa=aur*gamma_func(4.0+bur)
      tmpb=6.0*lamxx**(bur)
@@ -822,25 +822,25 @@ real function UhxN( types, qx, rhob, rho0, Nx )
 end function UhxN
 
 !---------------------------------
-! ʲ, ץ饤١ȴؿ
+! 以下, プライベート関数
 !---------------------------------
 
 real function lamx( types, qx, rhob, Nx )
-! ŷʪλؿؿʬۤˤ뷹׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 凝結物質の指数関数分布における傾きを計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: ncond, tmpa, tmpb, tmpc
 
   if(present(Nx))then
      tmpa=pi*Nx/rhob/qx
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('s')
         lamx=(tmpa*rhos)**(1.0/3.0)
      case ('g')
@@ -848,7 +848,7 @@ real function lamx( types, qx, rhob, Nx )
      end select
   else
      tmpa=pi/rhob/qx
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('r')
         lamx=(tmpa*rhow*nr0)**(0.25)
      case ('s')
@@ -863,28 +863,28 @@ real function lamx( types, qx, rhob, Nx )
 end function lamx
 
 real function nx0( types, qx, rhob, Nx )
-! ŷʪλؿؿʬۤˤ y Ҥ׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 凝結物質の指数関数分布における y 切片を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: ncond, tmpa, tmpb, tmpc
 
   if(present(Nx))then
      tmpa=pi*Nx/rhob/qx
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('s')
         lamx=Nx*(tmpa*rhos)**(1.0/3.0)
      case ('g')
         lamx=Nx*(tmpa*rhog)**(1.0/3.0)
      end select
   else
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('r')
         nx0=nr0
      case ('s')
