@@ -1,17 +1,17 @@
 !---------------------------------------------------------------
-! Copyright (C) 2009-2013 GFD Dennou Club. All rights reserved.
+! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
 module cloud_basic
-! CReSS αʪ
-! ܴؿǤ, ͤ礭ʪ̤Τ٤׻ФƤ,
-! ɤտŪ exp(log()) Ȥ׻Ԥä
-! 򤹤.
-! Ȥ, Ǥդʪ a**b ξ, exp(b*log(a)) .
-! ʤʤ, a**b=exp(log(a**b))=exp(b*log(a)) Ǥ.
-! ޤ, ʪ a*b ξ, exp(log(a)+log(b)) ȤƤ.
-! Τʪ̤껻äƤ,
-! exp(-a) Ȥ뤳Ȥǳ껻򤹤.
+! CReSS の雲物理過程
+! 本関数内では, 値の大きな物理量のべき乗計算が出てきた際,
+! 桁落ちを防ぐため意図的に exp(log()) という計算を行って
+! 回避する.
+! たとえば, 任意の物理量 a**b の場合, exp(b*log(a)) がそれに相当する.
+! なぜなら, a**b=exp(log(a**b))=exp(b*log(a)) だからである.
+! また, おおきな物理量 a*b の場合も, exp(log(a)+log(b)) としている.
+! これらのおおきな物理量が割り算に入っている場合,
+! exp(-a) とすることで割り算を回避する.
   use Thermo_Function
   use Thermo_Const
   use special_function
@@ -23,10 +23,10 @@ module cloud_basic
 contains
 
 real function Lv( temp )
-!  -> ǤǮǮ
+! 水 -> 水蒸気での潜熱加熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
+  real, intent(in) :: temp  ! 温度 [K]
 
   call ptcheck( temp, 'Lv' )
 
@@ -37,10 +37,10 @@ real function Lv( temp )
 end function Lv
 
 real function Ls( temp )
-! ɹ -> ǤǮǮ
+! 氷 -> 水蒸気での潜熱加熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
+  real, intent(in) :: temp ! 温度 [K]
 
   call ptcheck( temp, 'Ls' )
 
@@ -51,10 +51,10 @@ real function Ls( temp )
 end function Ls
 
 real function Lf( temp )
-!  -> ɹǤͻǮ
+! 水 -> 氷での融解熱
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
+  real, intent(in) :: temp ! 温度 [K]
 
   call ptcheck( temp,'Lf' )
 
@@ -65,11 +65,11 @@ real function Lf( temp )
 end function Lf
 
 real function nu_air( temp, pres )
-! ưǴ
+! 空気の動粘性係数
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
-  real, intent(in) :: pres !  [Pa]
+  real, intent(in) :: temp ! 温度 [K]
+  real, intent(in) :: pres ! 気圧 [Pa]
 
   call ptcheck( temp, 'nu air' )
 
@@ -80,10 +80,10 @@ real function nu_air( temp, pres )
 end function nu_air
 
 real function mu_air( temp, pres )
-! Ǵ
+! 空気の粘性係数
   implicit none
-  real, intent(in) :: temp !  [K]
-  real, intent(in) :: pres !  [Pa]
+  real, intent(in) :: temp ! 温度 [K]
+  real, intent(in) :: pres ! 気圧 [Pa]
   real :: rho
 
   call ptcheck( temp, 'mu air' )
@@ -97,11 +97,11 @@ real function mu_air( temp, pres )
 end function mu_air
 
 real function Dv( temp, pres )
-! γȻ
+! 水蒸気の拡散係数
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp !  [K]
-  real, intent(in) :: pres !  [Pa]
+  real, intent(in) :: temp ! 温度 [K]
+  real, intent(in) :: pres ! 気圧 [Pa]
 
   call ptcheck( temp, 'Dv' )
 
@@ -156,24 +156,24 @@ real function qvsi( temp, pres )
 end function qvsi
 
 !---------------------------------
-! ʲ, ץ饤١ȴؿ
+! 以下, プライベート関数
 !---------------------------------
 
 real function lamx( types, qx, rhob, Nx )
-! ŷʪλؿؿʬۤˤ뷹׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 凝結物質の指数関数分布における傾きを計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa
 
   if(qx>=qthres)then
-     if(present(Nx).and.types(1:1)/='r')then  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     if(present(Nx).and.types(1:1)/='r')then  ! 'r' は Nx を使わないので, 場合分けしない.
         tmpa=pi*Nx/rhob/qx
         select case (types(1:1))
         case ('s')
@@ -206,20 +206,20 @@ real function lamx( types, qx, rhob, Nx )
 end function lamx
 
 real function nx0( types, qx, rhob, Nx )
-! ŷʪλؿؿʬۤˤ y Ҥ׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 凝結物質の指数関数分布における y 切片を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa
 
   if(qx>=qthres)then
-     if(present(Nx).and.types(1:1)/='r')then  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     if(present(Nx).and.types(1:1)/='r')then  ! 'r' は Nx を使わないので, 場合分けしない.
         tmpa=pi*Nx/rhob/qx
         select case (types(1:1))
         case ('s')
@@ -252,12 +252,12 @@ end function nx0
 
 
 real function Knudsen( temp, pres )
-! Knudsen ׻.
+! Knudsen 数を計算する.
   use Cloud_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp   !  [k]
-  real, intent(in) :: pres   !  [Pa]
+  real, intent(in) :: temp   ! 温度 [k]
+  real, intent(in) :: pres   ! 圧力 [Pa]
 
   call ptcheck( temp, 'Knudsen' )
 
@@ -269,15 +269,15 @@ end function
 
 
 real function Daero( temp, pres )
-! γȻ׻.
-! , β٤ȼϤβ٤ƱȤƤ.
+! エアロゾルの拡散係数を計算する.
+! 現在, 雲水の温度と周囲の温度は同じとしている.
   use Cloud_Const
   use Thermo_Const
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: temp   !  [k]
-  real, intent(in) :: pres   !  [Pa]
+  real, intent(in) :: temp   ! 温度 [k]
+  real, intent(in) :: pres   ! 圧力 [Pa]
   real :: Tcl
 
   call ptcheck( temp, 'Daero' )
@@ -291,14 +291,14 @@ end function
 
 
 real function Naero( temp )
-! ܿˤοǻ٤׻.
-! Ǥϱγβ٤Ϥξ絤β٤ȤƷ׻Ƥ.
+! 接触凍結核の数濃度を計算する.
+! ここでは雲粒の温度はその場の大気の温度として計算している.
   use Cloud_Const
   use Thermo_Const
   use Phys_Const
   use Math_Const
   implicit none
-  real, intent(in) :: temp   !  [k]
+  real, intent(in) :: temp   ! 温度 [k]
 
   call ptcheck( temp, 'Naero' )
 
@@ -314,13 +314,13 @@ end function Naero
 
 
 real function Dbc( qc, rhob )
-! ñʬʬۤαʿľ¤׻. (4.51)
+! 単分散分布の雲水平均直径を計算する. (4.51)
   use Cloud_Const
   use Thermo_Const
   use Math_Const
   implicit none
-  real, intent(in) :: qc     ! 庮 [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
+  real, intent(in) :: qc     ! 雲水混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場密度 [kg/m3]
   real :: tmp
 
   tmp=6.0*rhob*qc/(pi*rhow*Nc)
@@ -332,15 +332,15 @@ end function Dbc
 
 
 real function Dbi( qi, rhob, Ni )
-! ñʬʬۤαɹʿľ¤׻. (4.52)
-! Ni ۤͿʤ, temp, pres, qv Ǥ.
+! 単分散分布の雲氷平均直径を計算する. (4.52)
+! Ni が陽に与えられない場合, temp, pres, qv から診断する.
   use Cloud_Const
   use Thermo_Const
   use Math_Const
   implicit none
-  real, intent(in) :: qi     ! ɹ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Ni     ! ɹοǻ [1/m3]
+  real, intent(in) :: qi     ! 雲氷混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場密度 [kg/m3]
+  real, intent(in), optional :: Ni     ! 雲氷の数濃度 [1/m3]
   real :: tmp, tmpNi
 
   if(present(Ni))then
@@ -362,11 +362,11 @@ end function Dbi
 
 
 real function Ni_calc( qi )
-! diagni.f90 Ѥ, ɹοǻ٤׻.
+! diagni.f90 を用いて, 氷晶の数濃度を計算する.
   use Cloud_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: qi     ! ɹκ [kg/kg]
+  real, intent(in) :: qi     ! 雲氷の混合比 [kg/kg]
 
   Ni_calc=4.0*qi/(3.0*mi0max)  
 
@@ -375,14 +375,14 @@ real function Ni_calc( qi )
 end function Ni_calc
 
 
-!real function Ni_calc( temp, pres, qv )  Ѥʤ.
-!! (4.75) Ѥ, ɹοǻ٤׻.
+!real function Ni_calc( temp, pres, qv )  これは用いない.
+!! (4.75) を用いて, 氷晶の数濃度を計算する.
 !  use Cloud_Const
 !  use Thermo_Const
 !  implicit none
-!  real, intent(in) :: temp   !  [K]
-!  real, intent(in) :: pres   !  [Pa]
-!  real, intent(in) :: qv     !  [kg/kg]
+!  real, intent(in) :: temp   ! 温度 [K]
+!  real, intent(in) :: pres   ! 圧力 [Pa]
+!  real, intent(in) :: qv     ! 水蒸気混合比 [kg/kg]
 !  real :: Si, temps, SSi, Swi, tmpa
 !  
 !  call ptcheck( temp )
@@ -413,7 +413,7 @@ end function Ni_calc
 
 real function Koenig1( temp )
   implicit none
-  real, intent(in) :: temp   !  [K]
+  real, intent(in) :: temp   ! 温度 [K]
   real :: tc
   real, dimension(32) :: param
   integer :: i
@@ -472,7 +472,7 @@ end function Koenig1
 
 real function Koenig2( temp )
   implicit none
-  real, intent(in) :: temp   !  [K]
+  real, intent(in) :: temp   ! 温度 [K]
   real :: tc
   real, dimension(32) :: param
   integer :: i
@@ -530,17 +530,17 @@ end function Koenig2
 
 
 real function Exy( typexy, temp, pres, qc, qx, rhob, rho0, Nx )
-! ʻˤªΨ.
+! 衝突併合における捕捉率を求める.
   use Cloud_Const
   implicit none
-  character(2), intent(in) :: typexy  ! ŷʪμ 'r' = , 's' = , 'g' = , 'c' = , 'i' = ɹ
-  real, intent(in), optional :: temp !  [K]
-  real, intent(in), optional :: pres !  [Pa]
-  real, intent(in), optional :: qc     ! κ [kg/kg]
-  real, intent(in), optional :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in), optional :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: rho0   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(2), intent(in) :: typexy  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰, 'c' = 雲水, 'i' = 雲氷
+  real, intent(in), optional :: temp ! 温度 [K]
+  real, intent(in), optional :: pres ! 気圧 [Pa]
+  real, intent(in), optional :: qc     ! 雲水の混合比 [kg/kg]
+  real, intent(in), optional :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in), optional :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: rho0   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmp_Stk
 
   if(typexy(1:1)=='c')then
@@ -576,18 +576,18 @@ end function Exy
 
 
 real function Stk( types, temp, pres, qc, qx, rhob, rho0, Nx )
-! ȡ׻. (4.110)
+! ストークス比を計算する. (4.110)
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: temp !  [K]
-  real, intent(in) :: pres !  [Pa]
-  real, intent(in) :: qc     ! κ [kg/kg]
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in) :: rho0   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: temp ! 温度 [K]
+  real, intent(in) :: pres ! 気圧 [Pa]
+  real, intent(in) :: qc     ! 雲水の混合比 [kg/kg]
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in) :: rho0   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
 
   real :: tmpDbc, Dy, Uby, mu
 
@@ -618,14 +618,14 @@ end function Stk
 
 
 real function Category_rs( qr, qs, rhob, Ns )
-! ξ͸ʬ۷׻. (4.113)
+! 雨と雪の衝突後の分配係数を計算する. (4.113)
   use Cloud_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: qr  ! κ [kg/kg]
-  real, intent(in) :: qs  ! κ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in), optional :: Ns  ! οǻ [1/m3]
+  real, intent(in) :: qr  ! 雨の混合比 [kg/kg]
+  real, intent(in) :: qs  ! 雪の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in), optional :: Ns  ! 雪の数濃度 [1/m3]
   real :: lamdas, lamdar, mbr, mbs
 
   if(qr>=qthres.and.qs>=qthres)then
@@ -657,9 +657,9 @@ real function Gw( temp, pres, rhob )
   use Math_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
   real :: tmpa, tmpb, tmpc, tmpd
 
   call ptcheck( temp, 'Gw' )
@@ -680,9 +680,9 @@ real function Gi( temp, pres, rhob )
   use Math_Const
   use Thermo_Const
   implicit none
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
   real :: tmpa, tmpb, tmpc, tmpd
 
   call ptcheck( temp, 'Gi' )
@@ -703,13 +703,13 @@ real function VENTx( types, temp, pres, qx, rhob, rho0, Nx )
   use Math_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: temp  !  [K]
-  real, intent(in) :: pres  !  [Pa]
-  real, intent(in) :: qx    ! types κ [kg/kg]
-  real, intent(in) :: rhob  ! ̩ [kg/m3]
-  real, intent(in) :: rho0  ! ɽ̤Ǥδ̩ [kg/m3]
-  real, intent(in), optional :: Nx    ! types οǻ [1/m3]
+  character(1), intent(in) :: types  ! 凝結物の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: temp  ! 温度 [K]
+  real, intent(in) :: pres  ! 圧力 [Pa]
+  real, intent(in) :: qx    ! types の混合比 [kg/kg]
+  real, intent(in) :: rhob  ! 基準密度 [kg/m3]
+  real, intent(in) :: rho0  ! 地表面での基準密度 [kg/m3]
+  real, intent(in), optional :: Nx    ! types の数濃度 [1/m3]
   real :: tmp, tmpa, tmpb, tmpc, aux, bux, ny0, lamdax
 
   call ptcheck( temp, 'VENTx' )
@@ -758,17 +758,17 @@ end function VENTx
 
 
 real function UbxN( types, qx, rhob, rho0, Nx )
-! ǻ٤νŤߤ򤫤ƥ꡼ x νü®٤׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 数濃度の重みをかけたカテゴリー x の終端落下速度を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in) :: rho0   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in) :: rho0   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa, tmpb, tmpc, lamxx
 
   if(qx>=qthres)then
@@ -778,7 +778,7 @@ real function UbxN( types, qx, rhob, rho0, Nx )
         lamxx=lamx( types(1:1), qx, rhob )
      end if
 
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('r')
         tmpa=aur*gamma_func(1.0+bur)
         tmpb=exp(-bur*log(lamxx))
@@ -808,7 +808,7 @@ end function UbxN
 
 subroutine ptcheck( temp, rname )
   implicit none
-  real, intent(in) :: temp  !  [K]
+  real, intent(in) :: temp  ! 温度 [K]
   character(*), intent(in), optional :: rname  ! routine name
 
   if(temp>1000.0)then
@@ -825,17 +825,17 @@ end subroutine ptcheck
 
 
 real function UhxN( types, qx, rhob, rho0, Nx )
-! ̤νŤߤ򤫤ƥ꡼ x νü®٤׻.
-! ǻ٤ʤ, y ҤͤǲꤷƷ׻.
+! 重量の重みをかけたカテゴリー x の終端落下速度を計算する.
+! 数濃度がない場合は, y 切片を固定値で仮定して計算する.
   use Math_Const
   use Cloud_Const
   use Thermo_Const
   implicit none
-  character(1), intent(in) :: types  ! ŷʪμ 'r' = , 's' = , 'g' = 
-  real, intent(in) :: qx     ! ŷʪκ [kg/kg]
-  real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
-  real, intent(in) :: rho0   ! Ͼˤܾ̩ [kg/m3]
-  real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
+  character(1), intent(in) :: types  ! 凝結物質の種類 'r' = 雨, 's' = 雪, 'g' = 霰
+  real, intent(in) :: qx     ! 凝結物質の混合比 [kg/kg]
+  real, intent(in) :: rhob   ! 基本場の密度 [kg/m3]
+  real, intent(in) :: rho0   ! 地上における基本場の密度 [kg/m3]
+  real, intent(in), optional :: Nx  ! qx という凝結物質の数濃度
   real :: tmpa, tmpb, tmpc, lamxx
 
   if(qx>=qthres)then
@@ -846,7 +846,7 @@ real function UhxN( types, qx, rhob, rho0, Nx )
         lamxx=lamx( types(1:1), qx, rhob )
      end if
 
-     select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+     select case (types(1:1))  ! 'r' は Nx を使わないので, 場合分けしない.
      case ('r')
         tmpa=aur*gamma_func(4.0+bur)
         tmpb=exp(-(log(6.0)+bur*log(lamxx)))
@@ -877,14 +877,14 @@ end function UhxN
 subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err, ln )
   use Thermo_Const
   implicit none
-  real, intent(in) :: pres !  [Pa]
-  real, intent(inout) :: pt   !  [K]
-  real, intent(inout) :: qv   !  [kg kg-1]
-  real, intent(inout) :: qc   ! 庮 [kg kg-1]
+  real, intent(in) :: pres ! 圧力 [Pa]
+  real, intent(inout) :: pt   ! 温位 [K]
+  real, intent(inout) :: qv   ! 水蒸気混合比 [kg kg-1]
+  real, intent(inout) :: qc   ! 雲水混合比 [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
-  integer, intent(in), optional :: ln  ! 롼ײ
-                                       ! 줬ꤵ줿, иˤ
-                                       ! 롼ǤڤȽǤϹԤʤ.
+  integer, intent(in), optional :: ln  ! ループ回数
+                                       ! これが設定された場合, 相対誤差による
+                                       ! ループ打ち切り判断は行わない.
   real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, gam1, coe, pt1, qv1, qc1, err_max
   real :: tmp_err
   integer :: cn
@@ -971,14 +971,14 @@ end subroutine Moist_Sature_Adjust
 subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err, ln )
   use Thermo_Const
   implicit none
-  real, intent(in) :: pres !  [Pa]
-  real, intent(inout) :: pt   !  [K]
-  real, intent(inout) :: qv   !  [kg kg-1]
-  real, intent(inout) :: qi   ! ɹ [kg kg-1]
+  real, intent(in) :: pres ! 圧力 [Pa]
+  real, intent(inout) :: pt   ! 温位 [K]
+  real, intent(inout) :: qv   ! 水蒸気混合比 [kg kg-1]
+  real, intent(inout) :: qi   ! 雲氷混合比 [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
-  integer, intent(in), optional :: ln  ! 롼ײ
-                                       ! 줬ꤵ줿, иˤ
-                                       ! 롼ǤڤȽǤϹԤʤ.
+  integer, intent(in), optional :: ln  ! ループ回数
+                                       ! これが設定された場合, 相対誤差による
+                                       ! ループ打ち切り判断は行わない.
   real :: tmppt, tmpqv, tmpqi, dqi, temp, gam, gam1, coe, pt1, qv1, qi1, err_max
   real :: tmp_err
   integer :: cn
