@@ -58,11 +58,11 @@ subroutine ffttp_1df( nx, a, b, csign, prim, prim_fact, omega_fix, omegan_fix )
   complex, intent(in), dimension(0:nx-1) :: a  ! 入力配列
   complex, intent(inout), dimension(0:nx-1) :: b  ! 出力配列
   character(1), intent(in) :: csign  ! 正逆変換判定 [r=正変換, i=逆変換]
-  character(1), optional, intent(in) :: prim  ! 素因数分解をするかどうか
+  character(1), intent(in), optional :: prim  ! 素因数分解をするかどうか
   ! [o=分解する, x=分解しない] default=分解しない. その場合は, 通常の DFT.
   ! 素因数分解する場合, nx=2^a*3^b*5^c*7^d までしか分解しないようにする.
   ! ただし, 'x' のときでも, prim_fact が設定されていれば, そのべきで FFT する.
-  integer, dimension(5), optional :: prim_fact  ! prim = x のとき設定すると
+  integer, dimension(5), intent(in), optional :: prim_fact  ! prim = x のとき設定すると
   ! そのべきで FFT を行う. prim_fact=(/a,b,c,d,e/) : 2^a*3^b*5^c*7^d*e
   complex, dimension(0:nx-1,0:nx-1), intent(in), optional :: omega_fix
                        ! 余素因数に対応する回転行列
@@ -295,11 +295,11 @@ subroutine ffttp_1dd( nx, a, b, csign, prim, prim_fact, omega_fix, omegan_fix )
   complex(kind(0d0)), intent(in), dimension(0:nx-1) :: a  ! 入力配列
   complex(kind(0d0)), intent(inout), dimension(0:nx-1) :: b  ! 出力配列
   character(1), intent(in) :: csign  ! 正逆変換判定 [r=正変換, i=逆変換]
-  character(1), optional, intent(in) :: prim  ! 素因数分解をするかどうか
+  character(1), intent(in), optional :: prim  ! 素因数分解をするかどうか
   ! [o=分解する, x=分解しない] default=分解しない. その場合は, 通常の DFT.
   ! 素因数分解する場合, nx=2^a*3^b*5^c*7^d までしか分解しないようにする.
   ! ただし, 'x' のときでも, prim_fact が設定されていれば, そのべきで FFT する.
-  integer, dimension(5), optional :: prim_fact  ! prim = x のとき設定すると
+  integer, dimension(5), intent(in), optional :: prim_fact  ! prim = x のとき設定すると
   ! そのべきで FFT を行う. prim_fact=(/a,b,c,d,e/) : 2^a*3^b*5^c*7^d*e
   complex(kind(0d0)), dimension(0:nx-1,0:nx-1), intent(in), optional :: omega_fix
                        ! 余素因数に対応する回転行列
