@@ -2,7 +2,7 @@
 ! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
 !---------------------------------------------------------------
 
-module Poly_Function  ! 𑽍vZTu[`W
+module Poly_Function  ! 直交多項式を計算するサブルーチン集
 
 interface CHEBYSHEV
 
@@ -56,18 +56,18 @@ end interface
 contains
 subroutine CHEBYSHEV_f(n, x, che)
 !****************************************
-!*** `FrVFtQ̃Tu[` ***
+!*** チェビシェフ漸化式のサブルーチン ***
 !****************************************
   implicit none
-  integer, intent(in) :: n  ! vZ`FrVFt̍ō
-  real, intent(in) :: x(:)  ! `FrVFẗ
-  real, intent(inout) :: che(0:n,size(x))  ! vZ`FrVFt
+  integer, intent(in) :: n  ! 計算するチェビシェフの最高次数
+  real, intent(in) :: x(:)  ! チェビシェフ多項式の引数
+  real, intent(inout) :: che(0:n,size(x))  ! 計算するチェビシェフ多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      che(0,i)=1.0
   end do
@@ -79,7 +79,7 @@ subroutine CHEBYSHEV_f(n, x, che)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               che(j+1,i)=2.0*che(1,i)*che(j,i)-che(j-1,i)
@@ -92,18 +92,18 @@ end  subroutine
 
 subroutine CHEBYSHEV_d(n, x, che)
 !****************************************
-!*** `FrVFtQ̃Tu[` ***
+!*** チェビシェフ漸化式のサブルーチン ***
 !****************************************
   implicit none
-  integer, intent(in) :: n  ! vZ`FrVFt̍ō
-  double precision, intent(in) :: x(:)  ! `FrVFẗ
+  integer, intent(in) :: n  ! 計算するチェビシェフの最高次数
+  double precision, intent(in) :: x(:)  ! チェビシェフ多項式の引数
   double precision, intent(inout) :: che(0:n,size(x))
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      che(0,i)=1.0d0
   end do
@@ -115,7 +115,7 @@ subroutine CHEBYSHEV_d(n, x, che)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               che(j+1,i)=2.0d0*che(1,i)*che(j,i)-che(j-1,i)
@@ -129,22 +129,22 @@ end subroutine
 
 subroutine GEGENBAUER_f(n, x, p, lambda)
 !************************************
-!*  Q[QoEA[ vZTu[`  *
+!*  ゲーゲンバウアー 多項式計算サブルーチン  *
 !************************************
-!* g
-!* n=(0w\)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! vZQ[QoEA[̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(in) :: lambda  ! Q[QoEA[W
-  real, intent(inout) :: p(0:n,size(x))  ! vZQ[QoEA[
+  integer, intent(in) :: n  ! 計算するゲーゲンバウアー多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(in) :: lambda  ! ゲーゲンバウアー係数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算するゲーゲンバウアー多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -156,7 +156,7 @@ subroutine GEGENBAUER_f(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))*(2.0*(lambda+real(j))*x(i)*p(j,i)  &
@@ -170,22 +170,22 @@ end subroutine
 
 subroutine GEGENBAUER_d(n, x, p, lambda)
 !************************************
-!*  Q[QoEA[ vZTu[`  *
+!*  ゲーゲンバウアー 多項式計算サブルーチン  *
 !************************************
-!* g
-!* n=(0w\)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! vZQ[QoEA[̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(in) :: lambda  ! Q[QoEA[W
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZQ[QoEA[
+  integer, intent(in) :: n  ! 計算するゲーゲンバウアー多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(in) :: lambda  ! ゲーゲンバウアー係数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算するゲーゲンバウアー多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -197,7 +197,7 @@ subroutine GEGENBAUER_d(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))*(2.0d0*(lambda+dble(j))*x(i)*p(j,i)  &
@@ -212,21 +212,21 @@ end subroutine
 
 subroutine HERMITE_f(n, x, p)
 !************************************
-!*  Hermite vZTu[`  *
+!*  Hermite 多項式計算サブルーチン  *
 !************************************
-!* g
-!* n=(0w\)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! vZ Hermite ̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! vZ Hermite 
+  integer, intent(in) :: n  ! 計算する Hermite 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Hermite 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -238,7 +238,7 @@ subroutine HERMITE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=2.0*(x(i)*p(j,i)-real(j)*p(j-1,i))
@@ -252,21 +252,21 @@ end subroutine
 
 subroutine HERMITE_d(n, x, p)
 !************************************
-!*  Hermite vZTu[`  *
+!*  Hermite 多項式計算サブルーチン  *
 !************************************
-!* g
-!* n=(0w\)
+!* 使い方
+!* n=次数(0次から指定可能)
 !************************************
   implicit none
-  integer, intent(in) :: n  ! vZ Hermit ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Hermit 
+  integer, intent(in) :: n  ! 計算する Hermit 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Hermit 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -278,7 +278,7 @@ subroutine HERMITE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=2.0d0*(x(i)*p(j,i)-dble(j)*p(j-1,i))
@@ -292,30 +292,30 @@ end subroutine
 
 subroutine JACOBI_POLY_f(n, x, p, alpha, beta)
 !***********************************
-!  Jacobi vZTu[`   *
+!  Jacobi 多項式計算サブルーチン   *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
-  real, intent(in) :: alpha  ! 
-  real, intent(in) :: beta  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  real, intent(in) :: alpha  ! 第一引数
+  real, intent(in) :: beta  ! 第二引数
   real :: gamma, omega
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- W̐ݒ ---
+!-- 係数の設定 ---
   gamma=alpha+beta
   omega=alpha-beta
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -327,7 +327,7 @@ subroutine JACOBI_POLY_f(n, x, p, alpha, beta)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(0.5/(real(j+1)*real(j+1+gamma)*real(2.0*j+gamma)))  &
@@ -346,30 +346,30 @@ end subroutine
 
 subroutine JACOBI_POLY_d(n, x, p, alpha, beta)
 !***********************************
-!  Jacobi vZTu[`   *
+!  Jacobi 多項式計算サブルーチン   *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
-  double precision, intent(in) :: alpha  ! 
-  double precision, intent(in) :: beta  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  double precision, intent(in) :: alpha  ! 第一引数
+  double precision, intent(in) :: beta  ! 第二引数
   double precision :: gamma, omega
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- W̐ݒ ---
+!-- 係数の設定 ---
   gamma=alpha+beta
   omega=alpha-beta
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -381,7 +381,7 @@ subroutine JACOBI_POLY_d(n, x, p, alpha, beta)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(0.5d0/(dble(j+1)*dble(j+1+gamma)*dble(2.0*j+gamma)))  &
@@ -400,23 +400,23 @@ end subroutine
 
 subroutine LAGUERRE_f(n, x, p)
 !***********************************
-!  Laguerre vZTu[` *
+!  Laguerre 多項式計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -428,7 +428,7 @@ subroutine LAGUERRE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(2.0*real(j)+1.0-x(i))*p(j,i)  &
@@ -443,23 +443,23 @@ end subroutine
 
 subroutine LAGUERRE_d(n, x, p)
 !***********************************
-!  Laguerre vZTu[` *
+!  Laguerre 多項式計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -471,7 +471,7 @@ subroutine LAGUERRE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(2.0d0*dble(j)+1.0d0-x(i))*p(j,i)  &
@@ -486,23 +486,23 @@ end subroutine
 
 subroutine LEGENDRE_f(n, x, p)
 !***********************************
-!  Legendre vZTu[` *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -514,7 +514,7 @@ subroutine LEGENDRE_f(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))*(p(j,i)*(2.0*real(j)+1.0)  &
@@ -529,23 +529,23 @@ end subroutine
 
 subroutine LEGENDRE_d(n, x, p)
 !***********************************
-!  Legendre vZTu[` *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -557,7 +557,7 @@ subroutine LEGENDRE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))*(p(j,i)*(2.0d0*dble(j)+1.0d0)  &
@@ -571,28 +571,28 @@ end subroutine
 
 subroutine AS_LEGENDRE_f(n, m, x, p)
 !***********************************
-!  Legendre ֐vZTu[` *
+!  Legendre 陪関数計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! m=(n>=m)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! m=随伴次数(n>=m)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ legendre ֐̍ō
-  integer, intent(in) :: m  ! vZ legendre ֐̐
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,-m:m,size(x))  ! vZ legendre ֐
+  integer, intent(in) :: n  ! 計算する legendre 陪関数の最高次数
+  integer, intent(in) :: m  ! 計算する legendre 陪関数の随伴次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,-m:m,size(x))  ! 計算する legendre 陪関数
   integer :: i, j, k, abm
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
   if(m>n)then
   end if
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,0,i)=1.0
   end do
@@ -605,7 +605,7 @@ subroutine AS_LEGENDRE_f(n, m, x, p)
         end do
 
         if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
            do j=1,n-1
               do i=1,nmax
                  p(j+1,k,i)=(1.0/real(j-k+1))*(p(j,k,i)*(2.0*real(j)+1.0)  &
@@ -621,23 +621,23 @@ end subroutine
 
 subroutine LEGENDRE_d(n, x, p)
 !***********************************
-!  Legendre vZTu[` *
+!  Legendre 多項式計算サブルーチン *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -649,7 +649,7 @@ subroutine LEGENDRE_d(n, x, p)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))*(p(j,i)*(2.0d0*dble(j)+1.0d0)  &
@@ -664,24 +664,24 @@ end subroutine
 
 subroutine SONINE_f(n, x, p, lambda)
 !***********************************
-!  Sonine vZTu[`  *
+!  Sonine 多項式計算サブルーチン  *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  real, intent(in) :: x(:)  ! 
-  real, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
-  real, intent(in) :: lambda  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  real, intent(in) :: x(:)  ! 引数
+  real, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  real, intent(in) :: lambda  ! 第一引数
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0
   end do
@@ -693,7 +693,7 @@ subroutine SONINE_f(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0/real(j+1))  &
@@ -709,24 +709,24 @@ end subroutine
 
 subroutine SONINE_d(n, x, p, lambda)
 !***********************************
-!  Sonine vZTu[`  *
+!  Sonine 多項式計算サブルーチン  *
 !***********************************
-! g
-! n=(0w\)
-! nmax=Ԋiq_
-! p=p(0:n,nmax) 2z
+! 使い方
+! n=次数(0次から指定可能)
+! nmax=空間格子点数
+! p=p(0:n,nmax) の2次元配列
 !***********************************
   implicit none
-  integer, intent(in) :: n  ! vZ jacobi ̍ō
-  double precision, intent(in) :: x(:)  ! 
-  double precision, intent(inout) :: p(0:n,size(x))  ! vZ Jacobi 
-  double precision, intent(in) :: lambda  ! 
+  integer, intent(in) :: n  ! 計算する jacobi 多項式の最高次数
+  double precision, intent(in) :: x(:)  ! 引数
+  double precision, intent(inout) :: p(0:n,size(x))  ! 計算する Jacobi 多項式
+  double precision, intent(in) :: lambda  ! 第一引数
   integer :: i, j
-  integer :: nmax  ! z x ̗vf
+  integer :: nmax  ! 引数配列 x の要素数
 
   nmax=size(x)
 
-!-- ̐ݒ ---
+!-- 初項の設定 ---
   do i=1,nmax
      p(0,i)=1.0d0
   end do
@@ -738,7 +738,7 @@ subroutine SONINE_d(n, x, p, lambda)
      end do
 
      if(n > 1)then
-!-- Q̌vZ ---
+!-- 漸化式の計算 ---
         do j=1,n-1
            do i=1,nmax
               p(j+1,i)=(1.0d0/dble(j+1))  &
