@@ -1538,7 +1538,7 @@ real function moist_laps_temp( p_stan, T_stan, p, dl )
   real, intent(in) :: T_stan  ! 基準温度 [K]
   real, intent(in) :: p  ! 求める高度における気圧 [Pa]
   integer, intent(in), optional :: dl  ! デバッグレベル
-  real :: seqpt, t_temp, seqpt_temp, dt, seqpt_temp2
+  real :: seqpt, t_temp, seqpt_temp, dt, seqpt_temp2, pre_seqpt_temp
   integer, parameter :: ilim=20
   real, parameter :: limit=2.0e-4
 
@@ -1559,6 +1559,7 @@ real function moist_laps_temp( p_stan, T_stan, p, dl )
   end do
 
   seqpt_temp=seqpt_temp2
+  pre_seqpt_temp=seqpt_temp  ! limit 前に dt が 0 に収束してしまった場合の救済措置
   dt=1.0
 
   do while ( abs(seqpt_temp-seqpt) > limit )
@@ -1572,7 +1573,11 @@ real function moist_laps_temp( p_stan, T_stan, p, dl )
      end if
 
      seqpt_temp=thetaes_Bolton( t_temp, p )
-
+     if(pre_seqpt_temp==seqpt_temp)then
+        dt=1.0  ! limit 前に dt がゼロに収束してしまったら, dt=1 からやり直し
+     end if
+     pre_seqpt_temp=seqpt_temp
+     
   end do
 
   moist_laps_temp=t_temp
